Class: Google::Apis::MigrationcenterV1alpha1::AssetFrame

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Contains data reported from an inventory source on an asset.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssetFrame

Returns a new instance of AssetFrame.



900
901
902
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 900

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attributesHash<String,String>

Generic asset attributes. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


695
696
697
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 695

def attributes
  @attributes
end

#aws_api_gateway_rest_api_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsApiGatewayRestApiDetails

Asset information specific for AWS API Gateway REST APIs. Corresponds to the JSON property awsApiGatewayRestApiDetails



700
701
702
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 700

def aws_api_gateway_rest_api_details
  @aws_api_gateway_rest_api_details
end

#aws_app_sync_graphql_api_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsAppSyncGraphqlApiDetails

Asset information specific for AWS AppSync GraphQL APIs. Corresponds to the JSON property awsAppSyncGraphqlApiDetails



705
706
707
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 705

def aws_app_sync_graphql_api_details
  @aws_app_sync_graphql_api_details
end

#aws_application_load_balancer_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsApplicationLoadBalancerDetails

Asset information specific for AWS Application Load Balancers. Corresponds to the JSON property awsApplicationLoadBalancerDetails



710
711
712
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 710

def aws_application_load_balancer_details
  @aws_application_load_balancer_details
end

#aws_athena_work_group_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsAthenaWorkGroupDetails

Contains details for an AWS Athena Work Group asset. Corresponds to the JSON property awsAthenaWorkGroupDetails



715
716
717
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 715

def aws_athena_work_group_details
  @aws_athena_work_group_details
end

#aws_autoscaling_group_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsAutoscalingGroupDetails

Asset information specific for AWS Autoscaling Group. Corresponds to the JSON property awsAutoscalingGroupDetails



720
721
722
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 720

def aws_autoscaling_group_details
  @aws_autoscaling_group_details
end

#aws_batch_compute_environment_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsBatchComputeEnvironmentDetails

Asset information specific for AWS Batch Compute Environments. Corresponds to the JSON property awsBatchComputeEnvironmentDetails



725
726
727
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 725

def aws_batch_compute_environment_details
  @aws_batch_compute_environment_details
end

#aws_cloud_front_distribution_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsCloudFrontDistributionDetails

Details of an AWS CloudFront distribution. Corresponds to the JSON property awsCloudFrontDistributionDetails



730
731
732
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 730

def aws_cloud_front_distribution_details
  @aws_cloud_front_distribution_details
end

#aws_dynamodb_table_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsDynamoDbTableDetails

Details of an AWS DynamoDB table. Corresponds to the JSON property awsDynamodbTableDetails



735
736
737
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 735

def aws_dynamodb_table_details
  @aws_dynamodb_table_details
end

#aws_ebs_volume_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEbsVolumeDetails

Asset information specific for AWS EBS Volumes. Corresponds to the JSON property awsEbsVolumeDetails



740
741
742
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 740

def aws_ebs_volume_details
  @aws_ebs_volume_details
end

#aws_ecr_repository_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEcrRepositoryDetails

Asset information specific for AWS ECR Repository. Corresponds to the JSON property awsEcrRepositoryDetails



745
746
747
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 745

def aws_ecr_repository_details
  @aws_ecr_repository_details
end

#aws_ecs_cluster_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEcsClusterDetails

Details of an AWS ECS cluster. Corresponds to the JSON property awsEcsClusterDetails



750
751
752
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 750

def aws_ecs_cluster_details
  @aws_ecs_cluster_details
end

#aws_efs_file_system_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEfsFileSystemDetails

Details of an AWS EFS file system. Corresponds to the JSON property awsEfsFileSystemDetails



755
756
757
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 755

def aws_efs_file_system_details
  @aws_efs_file_system_details
end

#aws_eks_cluster_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEksClusterDetails

Asset information specific for AWS EKS clusters. Corresponds to the JSON property awsEksClusterDetails



760
761
762
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 760

def aws_eks_cluster_details
  @aws_eks_cluster_details
end

#aws_elastic_ip_address_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElasticIpAddressDetails

Asset information specific for AWS Elastic IP Addresses. Corresponds to the JSON property awsElasticIpAddressDetails



765
766
767
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 765

def aws_elastic_ip_address_details
  @aws_elastic_ip_address_details
end

#aws_elastic_network_interface_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElasticNetworkInterfaceDetails

Asset information specific for AWS Elastic Network Interfaces. Corresponds to the JSON property awsElasticNetworkInterfaceDetails



770
771
772
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 770

def aws_elastic_network_interface_details
  @aws_elastic_network_interface_details
end

#aws_elasticache_cluster_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElastiCacheClusterDetails

Details of an AWS ElastiCache Cluster. Corresponds to the JSON property awsElasticacheClusterDetails



775
776
777
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 775

def aws_elasticache_cluster_details
  @aws_elasticache_cluster_details
end

#aws_elb_load_balancer_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElbLoadBalancerDetails

Asset information specific for AWS Load Balancers. Corresponds to the JSON property awsElbLoadBalancerDetails



780
781
782
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 780

def aws_elb_load_balancer_details
  @aws_elb_load_balancer_details
end

#aws_emr_cluster_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEmrClusterDetails

Contains details for an AWS EMR Cluster asset. Corresponds to the JSON property awsEmrClusterDetails



785
786
787
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 785

def aws_emr_cluster_details
  @aws_emr_cluster_details
end

#aws_firehose_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsFirehoseDetails

Contains details for an AWS Firehose asset. Corresponds to the JSON property awsFirehoseDetails



790
791
792
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 790

def aws_firehose_details
  @aws_firehose_details
end

#aws_glue_job_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsGlueJobDetails

Contains details for an AWS Glue Job asset. Corresponds to the JSON property awsGlueJobDetails



795
796
797
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 795

def aws_glue_job_details
  @aws_glue_job_details
end

#aws_internet_gateway_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsInternetGatewayDetails

Asset information specific for AWS Internet Gateways. Corresponds to the JSON property awsInternetGatewayDetails



800
801
802
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 800

def aws_internet_gateway_details
  @aws_internet_gateway_details
end

#aws_kinesis_stream_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsKinesisStreamDetails

Contains details for an AWS Kinesis Stream asset. Corresponds to the JSON property awsKinesisStreamDetails



805
806
807
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 805

def aws_kinesis_stream_details
  @aws_kinesis_stream_details
end

#aws_lambda_function_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsLambdaFunctionDetails

Asset information specific for AWS Lambda functions. Corresponds to the JSON property awsLambdaFunctionDetails



810
811
812
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 810

def aws_lambda_function_details
  @aws_lambda_function_details
end

#aws_nat_gateway_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsNatGatewayDetails

Details of an AWS NAT Gateway. Corresponds to the JSON property awsNatGatewayDetails



815
816
817
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 815

def aws_nat_gateway_details
  @aws_nat_gateway_details
end

#aws_redshift_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsRedshiftDetails

Details of an AWS Redshift cluster. Corresponds to the JSON property awsRedshiftDetails



820
821
822
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 820

def aws_redshift_details
  @aws_redshift_details
end

#aws_route53_hosted_zone_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsRoute53HostedZoneDetails

Details of an AWS Route 53 Hosted Zone. Corresponds to the JSON property awsRoute53HostedZoneDetails



825
826
827
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 825

def aws_route53_hosted_zone_details
  @aws_route53_hosted_zone_details
end

#aws_s3_bucket_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsS3BucketDetails

Asset information specific for AWS S3 buckets. Corresponds to the JSON property awsS3BucketDetails



830
831
832
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 830

def aws_s3_bucket_details
  @aws_s3_bucket_details
end

#aws_sns_topic_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsSnsTopicDetails

Asset information specific for AWS SNS Topics. Corresponds to the JSON property awsSnsTopicDetails



835
836
837
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 835

def aws_sns_topic_details
  @aws_sns_topic_details
end

#aws_vpc_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsVpcDetails

Asset information specific for AWS VPCs. Corresponds to the JSON property awsVpcDetails



840
841
842
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 840

def aws_vpc_details
  @aws_vpc_details
end

#collection_typeString

Optional. Frame collection type, if not specified the collection type will be based on the source type of the source the frame was reported on. Corresponds to the JSON property collectionType

Returns:

  • (String)


846
847
848
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 846

def collection_type
  @collection_type
end

#database_deployment_detailsGoogle::Apis::MigrationcenterV1alpha1::DatabaseDeploymentDetails

The details of a database deployment asset. Corresponds to the JSON property databaseDeploymentDetails



851
852
853
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 851

def database_deployment_details
  @database_deployment_details
end

#database_detailsGoogle::Apis::MigrationcenterV1alpha1::DatabaseDetails

Details of a logical database. Corresponds to the JSON property databaseDetails



856
857
858
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 856

def database_details
  @database_details
end

#hosting_provider_detailsGoogle::Apis::MigrationcenterV1alpha1::HostingProviderDetails

Details about the hosting platform of the asset. Corresponds to the JSON property hostingProviderDetails



861
862
863
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 861

def hosting_provider_details
  @hosting_provider_details
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


866
867
868
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 866

def labels
  @labels
end

#machine_detailsGoogle::Apis::MigrationcenterV1alpha1::MachineDetails

Details of a machine. Corresponds to the JSON property machineDetails



871
872
873
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 871

def machine_details
  @machine_details
end

#performance_samplesArray<Google::Apis::MigrationcenterV1alpha1::PerformanceSample>

Asset performance data samples. Samples that are from more than 40 days ago or after tomorrow are ignored. Corresponds to the JSON property performanceSamples



877
878
879
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 877

def performance_samples
  @performance_samples
end

#report_timeString

The time the data was reported. Corresponds to the JSON property reportTime

Returns:

  • (String)


882
883
884
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 882

def report_time
  @report_time
end

#structured_attributesHash<String,Object>

Optional. Generic structured asset attributes. Corresponds to the JSON property structuredAttributes

Returns:

  • (Hash<String,Object>)


887
888
889
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 887

def structured_attributes
  @structured_attributes
end

#trace_tokenString

Optional. Trace token is optionally provided to assist with debugging and traceability. Corresponds to the JSON property traceToken

Returns:

  • (String)


893
894
895
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 893

def trace_token
  @trace_token
end

#virtual_machine_detailsGoogle::Apis::MigrationcenterV1alpha1::VirtualMachineDetails

Details of a VirtualMachine. Corresponds to the JSON property virtualMachineDetails



898
899
900
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 898

def virtual_machine_details
  @virtual_machine_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
942
943
944
945
946
947
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 905

def update!(**args)
  @attributes = args[:attributes] if args.key?(:attributes)
  @aws_api_gateway_rest_api_details = args[:aws_api_gateway_rest_api_details] if args.key?(:aws_api_gateway_rest_api_details)
  @aws_app_sync_graphql_api_details = args[:aws_app_sync_graphql_api_details] if args.key?(:aws_app_sync_graphql_api_details)
  @aws_application_load_balancer_details = args[:aws_application_load_balancer_details] if args.key?(:aws_application_load_balancer_details)
  @aws_athena_work_group_details = args[:aws_athena_work_group_details] if args.key?(:aws_athena_work_group_details)
  @aws_autoscaling_group_details = args[:aws_autoscaling_group_details] if args.key?(:aws_autoscaling_group_details)
  @aws_batch_compute_environment_details = args[:aws_batch_compute_environment_details] if args.key?(:aws_batch_compute_environment_details)
  @aws_cloud_front_distribution_details = args[:aws_cloud_front_distribution_details] if args.key?(:aws_cloud_front_distribution_details)
  @aws_dynamodb_table_details = args[:aws_dynamodb_table_details] if args.key?(:aws_dynamodb_table_details)
  @aws_ebs_volume_details = args[:aws_ebs_volume_details] if args.key?(:aws_ebs_volume_details)
  @aws_ecr_repository_details = args[:aws_ecr_repository_details] if args.key?(:aws_ecr_repository_details)
  @aws_ecs_cluster_details = args[:aws_ecs_cluster_details] if args.key?(:aws_ecs_cluster_details)
  @aws_efs_file_system_details = args[:aws_efs_file_system_details] if args.key?(:aws_efs_file_system_details)
  @aws_eks_cluster_details = args[:aws_eks_cluster_details] if args.key?(:aws_eks_cluster_details)
  @aws_elastic_ip_address_details = args[:aws_elastic_ip_address_details] if args.key?(:aws_elastic_ip_address_details)
  @aws_elastic_network_interface_details = args[:aws_elastic_network_interface_details] if args.key?(:aws_elastic_network_interface_details)
  @aws_elasticache_cluster_details = args[:aws_elasticache_cluster_details] if args.key?(:aws_elasticache_cluster_details)
  @aws_elb_load_balancer_details = args[:aws_elb_load_balancer_details] if args.key?(:aws_elb_load_balancer_details)
  @aws_emr_cluster_details = args[:aws_emr_cluster_details] if args.key?(:aws_emr_cluster_details)
  @aws_firehose_details = args[:aws_firehose_details] if args.key?(:aws_firehose_details)
  @aws_glue_job_details = args[:aws_glue_job_details] if args.key?(:aws_glue_job_details)
  @aws_internet_gateway_details = args[:aws_internet_gateway_details] if args.key?(:aws_internet_gateway_details)
  @aws_kinesis_stream_details = args[:aws_kinesis_stream_details] if args.key?(:aws_kinesis_stream_details)
  @aws_lambda_function_details = args[:aws_lambda_function_details] if args.key?(:aws_lambda_function_details)
  @aws_nat_gateway_details = args[:aws_nat_gateway_details] if args.key?(:aws_nat_gateway_details)
  @aws_redshift_details = args[:aws_redshift_details] if args.key?(:aws_redshift_details)
  @aws_route53_hosted_zone_details = args[:aws_route53_hosted_zone_details] if args.key?(:aws_route53_hosted_zone_details)
  @aws_s3_bucket_details = args[:aws_s3_bucket_details] if args.key?(:aws_s3_bucket_details)
  @aws_sns_topic_details = args[:aws_sns_topic_details] if args.key?(:aws_sns_topic_details)
  @aws_vpc_details = args[:aws_vpc_details] if args.key?(:aws_vpc_details)
  @collection_type = args[:collection_type] if args.key?(:collection_type)
  @database_deployment_details = args[:database_deployment_details] if args.key?(:database_deployment_details)
  @database_details = args[:database_details] if args.key?(:database_details)
  @hosting_provider_details = args[:hosting_provider_details] if args.key?(:hosting_provider_details)
  @labels = args[:labels] if args.key?(:labels)
  @machine_details = args[:machine_details] if args.key?(:machine_details)
  @performance_samples = args[:performance_samples] if args.key?(:performance_samples)
  @report_time = args[:report_time] if args.key?(:report_time)
  @structured_attributes = args[:structured_attributes] if args.key?(:structured_attributes)
  @trace_token = args[:trace_token] if args.key?(:trace_token)
  @virtual_machine_details = args[:virtual_machine_details] if args.key?(:virtual_machine_details)
end