Class: Google::Apis::MigrationcenterV1alpha1::AssetsExportJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Assets export job message.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ AssetsExportJob

Returns a new instance of AssetsExportJob.



1057
1058
1059
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1057

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#conditionGoogle::Apis::MigrationcenterV1alpha1::AssetsExportJobExportCondition

Conditions for selecting assets to export. Corresponds to the JSON property condition



997
998
999
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 997

def condition
  @condition
end

#create_timeString

Output only. Resource creation time. Corresponds to the JSON property createTime

Returns:

  • (String)


1002
1003
1004
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1002

def create_time
  @create_time
end

#inventoryGoogle::Apis::MigrationcenterV1alpha1::AssetsExportJobInventory

Configuration for asset inventory details exports. Corresponds to the JSON property inventory



1007
1008
1009
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1007

def inventory
  @inventory
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character. * Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


1018
1019
1020
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1018

def labels
  @labels
end

#nameString

Output only. Identifier. Resource name. Corresponds to the JSON property name

Returns:

  • (String)


1023
1024
1025
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1023

def name
  @name
end

#network_dependenciesGoogle::Apis::MigrationcenterV1alpha1::AssetsExportJobNetworkDependencies

Configuration for network dependencies exports. Corresponds to the JSON property networkDependencies



1028
1029
1030
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1028

def network_dependencies
  @network_dependencies
end

#performance_dataGoogle::Apis::MigrationcenterV1alpha1::AssetsExportJobPerformanceData

Configuration for performance data exports. Corresponds to the JSON property performanceData



1033
1034
1035
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1033

def performance_data
  @performance_data
end

#recent_executionsArray<Google::Apis::MigrationcenterV1alpha1::AssetsExportJobExecution>

Output only. Recent non expired executions of the job. Corresponds to the JSON property recentExecutions



1038
1039
1040
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1038

def recent_executions
  @recent_executions
end

#show_hiddenBoolean Also known as: show_hidden?

Optional. When this value is set to 'true' the response will include all assets, including those that are hidden. Corresponds to the JSON property showHidden

Returns:

  • (Boolean)


1044
1045
1046
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1044

def show_hidden
  @show_hidden
end

#signed_uri_destinationGoogle::Apis::MigrationcenterV1alpha1::SignedUriDestination

Signed URI destination configuration. Corresponds to the JSON property signedUriDestination



1050
1051
1052
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1050

def signed_uri_destination
  @signed_uri_destination
end

#update_timeString

Output only. Resource update time. Corresponds to the JSON property updateTime

Returns:

  • (String)


1055
1056
1057
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1055

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1062
1063
1064
1065
1066
1067
1068
1069
1070
1071
1072
1073
1074
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1062

def update!(**args)
  @condition = args[:condition] if args.key?(:condition)
  @create_time = args[:create_time] if args.key?(:create_time)
  @inventory = args[:inventory] if args.key?(:inventory)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @network_dependencies = args[:network_dependencies] if args.key?(:network_dependencies)
  @performance_data = args[:performance_data] if args.key?(:performance_data)
  @recent_executions = args[:recent_executions] if args.key?(:recent_executions)
  @show_hidden = args[:show_hidden] if args.key?(:show_hidden)
  @signed_uri_destination = args[:signed_uri_destination] if args.key?(:signed_uri_destination)
  @update_time = args[:update_time] if args.key?(:update_time)
end