Class: Google::Apis::MigrationcenterV1alpha1::AzureVmPlatformDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::AzureVmPlatformDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Azure VM specific details.
Instance Attribute Summary collapse
-
#hyperthreading ⇒ String
Whether the machine is hyperthreaded.
-
#location ⇒ String
The location of the machine in the Azure format.
-
#machine_type_label ⇒ String
Azure platform's machine type label.
-
#provisioning_state ⇒ String
Azure platform's provisioning state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AzureVmPlatformDetails
constructor
A new instance of AzureVmPlatformDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AzureVmPlatformDetails
Returns a new instance of AzureVmPlatformDetails.
1777 1778 1779 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1777 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hyperthreading ⇒ String
Whether the machine is hyperthreaded.
Corresponds to the JSON property hyperthreading
1760 1761 1762 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1760 def hyperthreading @hyperthreading end |
#location ⇒ String
The location of the machine in the Azure format.
Corresponds to the JSON property location
1765 1766 1767 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1765 def location @location end |
#machine_type_label ⇒ String
Azure platform's machine type label.
Corresponds to the JSON property machineTypeLabel
1770 1771 1772 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1770 def machine_type_label @machine_type_label end |
#provisioning_state ⇒ String
Azure platform's provisioning state.
Corresponds to the JSON property provisioningState
1775 1776 1777 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1775 def provisioning_state @provisioning_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1782 1783 1784 1785 1786 1787 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1782 def update!(**args) @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading) @location = args[:location] if args.key?(:location) @machine_type_label = args[:machine_type_label] if args.key?(:machine_type_label) @provisioning_state = args[:provisioning_state] if args.key?(:provisioning_state) end |