Class: Google::Apis::MigrationcenterV1alpha1::DiskUsageSample

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Disk usage sample. Values are across all disks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiskUsageSample

Returns a new instance of DiskUsageSample.



3497
3498
3499
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#average_iopsFloat

Average IOPS sampled over a short window. Must be non-negative. If read or write are set, the sum of read and write will override the value of the average_iops. Corresponds to the JSON property averageIops

Returns:

  • (Float)


3483
3484
3485
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3483

def average_iops
  @average_iops
end

#average_read_iopsFloat

Average read IOPS sampled over a short window. Must be non-negative. If both read and write are zero they are ignored. Corresponds to the JSON property averageReadIops

Returns:

  • (Float)


3489
3490
3491
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3489

def average_read_iops
  @average_read_iops
end

#average_write_iopsFloat

Average write IOPS sampled over a short window. Must be non-negative. If both read and write are zero they are ignored. Corresponds to the JSON property averageWriteIops

Returns:

  • (Float)


3495
3496
3497
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3495

def average_write_iops
  @average_write_iops
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3502
3503
3504
3505
3506
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3502

def update!(**args)
  @average_iops = args[:average_iops] if args.key?(:average_iops)
  @average_read_iops = args[:average_read_iops] if args.key?(:average_read_iops)
  @average_write_iops = args[:average_write_iops] if args.key?(:average_write_iops)
end