Class: Google::Apis::MigrationcenterV1alpha1::FrameViolationEntry

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that contains a single violation of a reported AssetFrame resource.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FrameViolationEntry

Returns a new instance of FrameViolationEntry.



3829
3830
3831
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3829

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#fieldString

The field of the original frame where the violation occurred. Corresponds to the JSON property field

Returns:

  • (String)


3822
3823
3824
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3822

def field
  @field
end

#violationString

A message describing the violation. Corresponds to the JSON property violation

Returns:

  • (String)


3827
3828
3829
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3827

def violation
  @violation
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3834
3835
3836
3837
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3834

def update!(**args)
  @field = args[:field] if args.key?(:field)
  @violation = args[:violation] if args.key?(:violation)
end