Class: Google::Apis::MigrationcenterV1alpha1::FstabEntry
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::FstabEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Single fstab entry.
Instance Attribute Summary collapse
-
#file ⇒ String
The mount point for the filesystem.
-
#freq ⇒ Fixnum
Used by dump to determine which filesystems need to be dumped.
-
#mntops ⇒ String
Mount options associated with the filesystem.
-
#passno ⇒ Fixnum
Used by the fsck(8) program to determine the order in which filesystem checks are done at reboot time.
-
#spec ⇒ String
The block special device or remote filesystem to be mounted.
-
#vfstype ⇒ String
The type of the filesystem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FstabEntry
constructor
A new instance of FstabEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FstabEntry
Returns a new instance of FstabEntry.
3919 3920 3921 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3919 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
The mount point for the filesystem.
Corresponds to the JSON property file
3891 3892 3893 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3891 def file @file end |
#freq ⇒ Fixnum
Used by dump to determine which filesystems need to be dumped.
Corresponds to the JSON property freq
3896 3897 3898 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3896 def freq @freq end |
#mntops ⇒ String
Mount options associated with the filesystem.
Corresponds to the JSON property mntops
3901 3902 3903 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3901 def mntops @mntops end |
#passno ⇒ Fixnum
Used by the fsck(8) program to determine the order in which filesystem checks
are done at reboot time.
Corresponds to the JSON property passno
3907 3908 3909 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3907 def passno @passno end |
#spec ⇒ String
The block special device or remote filesystem to be mounted.
Corresponds to the JSON property spec
3912 3913 3914 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3912 def spec @spec end |
#vfstype ⇒ String
The type of the filesystem.
Corresponds to the JSON property vfstype
3917 3918 3919 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3917 def vfstype @vfstype end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3924 3925 3926 3927 3928 3929 3930 3931 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3924 def update!(**args) @file = args[:file] if args.key?(:file) @freq = args[:freq] if args.key?(:freq) @mntops = args[:mntops] if args.key?(:mntops) @passno = args[:passno] if args.key?(:passno) @spec = args[:spec] if args.key?(:spec) @vfstype = args[:vfstype] if args.key?(:vfstype) end |