Class: Google::Apis::MigrationcenterV1alpha1::GenericPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Generic platform details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenericPlatformDetails

Returns a new instance of GenericPlatformDetails.



4031
4032
4033
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4031

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


4022
4023
4024
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4022

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different VMs in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


4029
4030
4031
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4029

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4036
4037
4038
4039
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4036

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end