Class: Google::Apis::MigrationcenterV1alpha1::Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that represents an asset group. The purpose of an asset group is to bundle a set of assets that have something in common, while allowing users to add annotations to the group. An asset can belong to multiple groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Group

Returns a new instance of Group.



4091
4092
4093
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4091

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the group was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4064
4065
4066
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4064

def create_time
  @create_time
end

#descriptionString

Optional. The description of the group. Corresponds to the JSON property description

Returns:

  • (String)


4069
4070
4071
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4069

def description
  @description
end

#display_nameString

Optional. User-friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


4074
4075
4076
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4074

def display_name
  @display_name
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4079
4080
4081
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4079

def labels
  @labels
end

#nameString

Output only. The name of the group. Corresponds to the JSON property name

Returns:

  • (String)


4084
4085
4086
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4084

def name
  @name
end

#update_timeString

Output only. The timestamp when the group was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4089
4090
4091
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4089

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4096
4097
4098
4099
4100
4101
4102
4103
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4096

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end