Class: Google::Apis::MigrationcenterV1alpha1::ImportDataFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that represents a payload file in an import job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportDataFile

Returns a new instance of ImportDataFile.



4492
4493
4494
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4492

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the file was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4465
4466
4467
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4465

def create_time
  @create_time
end

#display_nameString

Optional. User-friendly display name. Maximum length is 256 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


4470
4471
4472
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4470

def display_name
  @display_name
end

#formatString

Required. The payload format. Corresponds to the JSON property format

Returns:

  • (String)


4475
4476
4477
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4475

def format
  @format
end

#nameString

Output only. The name of the file. Corresponds to the JSON property name

Returns:

  • (String)


4480
4481
4482
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4480

def name
  @name
end

#stateString

Output only. The state of the import data file. Corresponds to the JSON property state

Returns:

  • (String)


4485
4486
4487
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4485

def state
  @state
end

#upload_file_infoGoogle::Apis::MigrationcenterV1alpha1::UploadFileInfo

A resource that contains a URI to which a data file can be uploaded. Corresponds to the JSON property uploadFileInfo



4490
4491
4492
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4490

def upload_file_info
  @upload_file_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4497
4498
4499
4500
4501
4502
4503
4504
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4497

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @format = args[:format] if args.key?(:format)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @upload_file_info = args[:upload_file_info] if args.key?(:upload_file_info)
end