Class: Google::Apis::MigrationcenterV1alpha1::ImportJob
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ImportJob
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A resource that represents the background job that imports asset frames.
Instance Attribute Summary collapse
-
#asset_source ⇒ String
Required.
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#display_name ⇒ String
User-friendly display name.
-
#execution_report ⇒ Google::Apis::MigrationcenterV1alpha1::ExecutionReport
A resource that reports result of the import job execution.
-
#gcs_payload ⇒ Google::Apis::MigrationcenterV1alpha1::GcsPayloadInfo
A resource that represents a payload hosted on Google Cloud Storage.
-
#inline_payload ⇒ Google::Apis::MigrationcenterV1alpha1::InlinePayloadInfo
A resource that represents the inline import job payload.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#validation_report ⇒ Google::Apis::MigrationcenterV1alpha1::ValidationReport
A resource that aggregates errors across import job files.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ImportJob
constructor
A new instance of ImportJob.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ImportJob
Returns a new instance of ImportJob.
4571 4572 4573 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4571 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset_source ⇒ String
Required. Reference to a source.
Corresponds to the JSON property assetSource
4514 4515 4516 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4514 def asset_source @asset_source end |
#complete_time ⇒ String
Output only. The timestamp when the import job was completed.
Corresponds to the JSON property completeTime
4519 4520 4521 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4519 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp when the import job was created.
Corresponds to the JSON property createTime
4524 4525 4526 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4524 def create_time @create_time end |
#display_name ⇒ String
User-friendly display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
4529 4530 4531 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4529 def display_name @display_name end |
#execution_report ⇒ Google::Apis::MigrationcenterV1alpha1::ExecutionReport
A resource that reports result of the import job execution.
Corresponds to the JSON property executionReport
4534 4535 4536 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4534 def execution_report @execution_report end |
#gcs_payload ⇒ Google::Apis::MigrationcenterV1alpha1::GcsPayloadInfo
A resource that represents a payload hosted on Google Cloud Storage.
Corresponds to the JSON property gcsPayload
4539 4540 4541 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4539 def gcs_payload @gcs_payload end |
#inline_payload ⇒ Google::Apis::MigrationcenterV1alpha1::InlinePayloadInfo
A resource that represents the inline import job payload.
Corresponds to the JSON property inlinePayload
4544 4545 4546 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4544 def inline_payload @inline_payload end |
#labels ⇒ Hash<String,String>
Labels as key value pairs.
Corresponds to the JSON property labels
4549 4550 4551 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4549 def labels @labels end |
#name ⇒ String
Output only. The full name of the import job.
Corresponds to the JSON property name
4554 4555 4556 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4554 def name @name end |
#state ⇒ String
Output only. The state of the import job.
Corresponds to the JSON property state
4559 4560 4561 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4559 def state @state end |
#update_time ⇒ String
Output only. The timestamp when the import job was last updated.
Corresponds to the JSON property updateTime
4564 4565 4566 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4564 def update_time @update_time end |
#validation_report ⇒ Google::Apis::MigrationcenterV1alpha1::ValidationReport
A resource that aggregates errors across import job files.
Corresponds to the JSON property validationReport
4569 4570 4571 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4569 def validation_report @validation_report end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 4587 4588 4589 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4576 def update!(**args) @asset_source = args[:asset_source] if args.key?(:asset_source) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @execution_report = args[:execution_report] if args.key?(:execution_report) @gcs_payload = args[:gcs_payload] if args.key?(:gcs_payload) @inline_payload = args[:inline_payload] if args.key?(:inline_payload) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @update_time = args[:update_time] if args.key?(:update_time) @validation_report = args[:validation_report] if args.key?(:validation_report) end |