Class: Google::Apis::MigrationcenterV1alpha1::IssueCompatibilityIssue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Details about a compatibility issue.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IssueCompatibilityIssue

Returns a new instance of IssueCompatibilityIssue.



4887
4888
4889
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4887

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#associated_objectString

Output only. Name of the object associated with this compatibility issue relative to the relevant asset. Does not represent a fully qualified resource name and is not intended for programmatic use. Corresponds to the JSON property associatedObject

Returns:

  • (String)


4868
4869
4870
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4868

def associated_object
  @associated_object
end

#associated_object_typeString

Output only. Type of object associated with this migration compatibility issue. Corresponds to the JSON property associatedObjectType

Returns:

  • (String)


4873
4874
4875
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4873

def associated_object_type
  @associated_object_type
end

#associated_valueString

Output only. A string representation of actual value associated with this issue. Some values may contain aggregated information, such as a flag name and the actual value assigned to it. Corresponds to the JSON property associatedValue

Returns:

  • (String)


4880
4881
4882
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4880

def associated_value
  @associated_value
end

#categoryString

Output only. Category of this compatibility issue. Corresponds to the JSON property category

Returns:

  • (String)


4885
4886
4887
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4885

def category
  @category
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4892
4893
4894
4895
4896
4897
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4892

def update!(**args)
  @associated_object = args[:associated_object] if args.key?(:associated_object)
  @associated_object_type = args[:associated_object_type] if args.key?(:associated_object_type)
  @associated_value = args[:associated_value] if args.key?(:associated_value)
  @category = args[:category] if args.key?(:category)
end