Class: Google::Apis::MigrationcenterV1alpha1::ListGroupsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ListGroupsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A response for listing groups.
Instance Attribute Summary collapse
-
#groups ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Group>
The list of Group Corresponds to the JSON property
groups. -
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListGroupsResponse
constructor
A new instance of ListGroupsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListGroupsResponse
Returns a new instance of ListGroupsResponse.
4888 4889 4890 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4888 def initialize(**args) update!(**args) end |
Instance Attribute Details
#groups ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Group>
The list of Group
Corresponds to the JSON property groups
4876 4877 4878 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4876 def groups @groups end |
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
4881 4882 4883 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4881 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
4886 4887 4888 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4886 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4893 4894 4895 4896 4897 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4893 def update!(**args) @groups = args[:groups] if args.key?(:groups) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |