Class: Google::Apis::MigrationcenterV1alpha1::ListOperationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ListOperationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
The response message for Operations.ListOperations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
The standard List next-page token.
-
#operations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Operation>
A list of operations that matches the specified filter in the request.
-
#unreachable ⇒ Array<String>
Unordered list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListOperationsResponse
constructor
A new instance of ListOperationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListOperationsResponse
Returns a new instance of ListOperationsResponse.
5135 5136 5137 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5135 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
5120 5121 5122 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5120 def next_page_token @next_page_token end |
#operations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Operation>
A list of operations that matches the specified filter in the request.
Corresponds to the JSON property operations
5125 5126 5127 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5125 def operations @operations end |
#unreachable ⇒ Array<String>
Unordered list. Unreachable resources. Populated when the request sets
ListOperationsRequest.return_partial_success and reads across collections.
For example, when attempting to list all resources across all supported
locations.
Corresponds to the JSON property unreachable
5133 5134 5135 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5133 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5140 5141 5142 5143 5144 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5140 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @operations = args[:operations] if args.key?(:operations) @unreachable = args[:unreachable] if args.key?(:unreachable) end |