Class: Google::Apis::MigrationcenterV1alpha1::ListRelationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ListRelationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Response message for listing relations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#relations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Relation>
A list of relations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRelationsResponse
constructor
A new instance of ListRelationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRelationsResponse
Returns a new instance of ListRelationsResponse.
5217 5218 5219 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5217 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
5210 5211 5212 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5210 def next_page_token @next_page_token end |
#relations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Relation>
A list of relations.
Corresponds to the JSON property relations
5215 5216 5217 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5215 def relations @relations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5222 5223 5224 5225 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5222 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @relations = args[:relations] if args.key?(:relations) end |