Class: Google::Apis::MigrationcenterV1alpha1::ListReportsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ListReportsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Response message for listing Reports.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#reports ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Report>
The list of Reports.
-
#unreachable ⇒ Array<String>
Locations that could not be reached.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListReportsResponse
constructor
A new instance of ListReportsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListReportsResponse
Returns a new instance of ListReportsResponse.
5303 5304 5305 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
5291 5292 5293 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5291 def next_page_token @next_page_token end |
#reports ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Report>
The list of Reports.
Corresponds to the JSON property reports
5296 5297 5298 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5296 def reports @reports end |
#unreachable ⇒ Array<String>
Locations that could not be reached.
Corresponds to the JSON property unreachable
5301 5302 5303 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5301 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5308 5309 5310 5311 5312 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5308 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @reports = args[:reports] if args.key?(:reports) @unreachable = args[:unreachable] if args.key?(:unreachable) end |