Class: Google::Apis::MigrationcenterV1alpha1::MachineDiskDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Details of machine disks.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachineDiskDetails

Returns a new instance of MachineDiskDetails.



5565
5566
5567
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5565

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#disksGoogle::Apis::MigrationcenterV1alpha1::DiskEntryList

VM disks. Corresponds to the JSON property disks



5546
5547
5548
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5546

def disks
  @disks
end

#raw_scan_resultString

Raw disk scan result. This field is intended for human inspection. The format of this field may be lsblk output or any another raw output. The exact format may change without notice and should not be relied upon. Corresponds to the JSON property rawScanResult

Returns:

  • (String)


5553
5554
5555
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5553

def raw_scan_result
  @raw_scan_result
end

#total_capacity_bytesFixnum

Disk total Capacity. Corresponds to the JSON property totalCapacityBytes

Returns:

  • (Fixnum)


5558
5559
5560
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5558

def total_capacity_bytes
  @total_capacity_bytes
end

#total_free_bytesFixnum

Total disk free space. Corresponds to the JSON property totalFreeBytes

Returns:

  • (Fixnum)


5563
5564
5565
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5563

def total_free_bytes
  @total_free_bytes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5570
5571
5572
5573
5574
5575
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5570

def update!(**args)
  @disks = args[:disks] if args.key?(:disks)
  @raw_scan_result = args[:raw_scan_result] if args.key?(:raw_scan_result)
  @total_capacity_bytes = args[:total_capacity_bytes] if args.key?(:total_capacity_bytes)
  @total_free_bytes = args[:total_free_bytes] if args.key?(:total_free_bytes)
end