Class: Google::Apis::MigrationcenterV1alpha1::OperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::OperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationMetadata
constructor
A new instance of OperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationMetadata
Returns a new instance of OperationMetadata.
6459 6460 6461 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6459 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
6423 6424 6425 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6423 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
6428 6429 6430 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6428 def create_time @create_time end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
6433 6434 6435 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6433 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have been cancelled successfully have Operation.
error value with a google.rpc.Status.code of 1, corresponding to Code.
CANCELLED.
Corresponds to the JSON property requestedCancellation
6441 6442 6443 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6441 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
6447 6448 6449 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6447 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
6452 6453 6454 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6452 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
6457 6458 6459 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6457 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6464 6465 6466 6467 6468 6469 6470 6471 6472 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6464 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |