Class: Google::Apis::MigrationcenterV1alpha1::PhysicalPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Platform specific details for Physical Machines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhysicalPlatformDetails

Returns a new instance of PhysicalPlatformDetails.



6610
6611
6612
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6610

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


6601
6602
6603
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6601

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different machines in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


6608
6609
6610
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6608

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6615
6616
6617
6618
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6615

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end