Class: Google::Apis::MigrationcenterV1alpha1::RemoveAssetsFromGroupRequest
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::RemoveAssetsFromGroupRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A request to remove assets from a group.
Instance Attribute Summary collapse
-
#allow_missing ⇒ Boolean
(also: #allow_missing?)
Optional.
-
#assets ⇒ Google::Apis::MigrationcenterV1alpha1::AssetList
Lists the asset IDs of all assets.
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RemoveAssetsFromGroupRequest
constructor
A new instance of RemoveAssetsFromGroupRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RemoveAssetsFromGroupRequest
Returns a new instance of RemoveAssetsFromGroupRequest.
6839 6840 6841 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6839 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_missing ⇒ Boolean Also known as: allow_missing?
Optional. When this value is set to false and one of the given assets is not
an existing member of the group, the operation fails with a Not Found error.
When set to true this situation is silently ignored by the server. Default
value is false.
Corresponds to the JSON property allowMissing
6817 6818 6819 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6817 def allow_missing @allow_missing end |
#assets ⇒ Google::Apis::MigrationcenterV1alpha1::AssetList
Lists the asset IDs of all assets.
Corresponds to the JSON property assets
6823 6824 6825 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6823 def assets @assets end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
6837 6838 6839 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6837 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6844 6845 6846 6847 6848 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6844 def update!(**args) @allow_missing = args[:allow_missing] if args.key?(:allow_missing) @assets = args[:assets] if args.key?(:assets) @request_id = args[:request_id] if args.key?(:request_id) end |