Class: Google::Apis::MigrationcenterV1alpha1::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Report represents a point-in-time rendering of the ReportConfig results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



7046
7047
7048
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7046

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


7008
7009
7010
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7008

def create_time
  @create_time
end

#descriptionString

Free-text description. Corresponds to the JSON property description

Returns:

  • (String)


7013
7014
7015
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7013

def description
  @description
end

#display_nameString

User-friendly display name. Maximum length is 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


7018
7019
7020
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7018

def display_name
  @display_name
end

#nameString

Output only. Name of resource. Corresponds to the JSON property name

Returns:

  • (String)


7023
7024
7025
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7023

def name
  @name
end

#stateString

Report creation state. Corresponds to the JSON property state

Returns:

  • (String)


7028
7029
7030
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7028

def state
  @state
end

#summaryGoogle::Apis::MigrationcenterV1alpha1::ReportSummary

Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report. Corresponds to the JSON property summary



7034
7035
7036
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7034

def summary
  @summary
end

#typeString

Report type. Corresponds to the JSON property type

Returns:

  • (String)


7039
7040
7041
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7039

def type
  @type
end

#update_timeString

Output only. Last update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


7044
7045
7046
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7044

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7051
7052
7053
7054
7055
7056
7057
7058
7059
7060
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7051

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @summary = args[:summary] if args.key?(:summary)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end