Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryChartData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Describes a collection of data points rendered as a Chart.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryChartData

Returns a new instance of ReportSummaryChartData.



7432
7433
7434
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7432

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#data_pointsArray<Google::Apis::MigrationcenterV1alpha1::ReportSummaryChartDataDataPoint>

Each data point in the chart is represented as a name-value pair with the name being the x-axis label, and the value being the y-axis value. Corresponds to the JSON property dataPoints



7430
7431
7432
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7430

def data_points
  @data_points
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7437
7438
7439
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7437

def update!(**args)
  @data_points = args[:data_points] if args.key?(:data_points)
end