Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryGroupPreferenceSetFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Summary Findings for a specific Group/PreferenceSet combination.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryGroupPreferenceSetFinding

Returns a new instance of ReportSummaryGroupPreferenceSetFinding.



7669
7670
7671
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7669

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#database_findingGoogle::Apis::MigrationcenterV1alpha1::ReportSummaryDatabaseFinding

DatabaseFinding contains an aggregate costs and shapes for a single database type. Corresponds to the JSON property databaseFinding



7564
7565
7566
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7564

def database_finding
  @database_finding
end

#descriptionString

Description for the Preference Set. Corresponds to the JSON property description

Returns:

  • (String)


7569
7570
7571
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7569

def description
  @description
end

#display_nameString

Display Name of the Preference Set Corresponds to the JSON property displayName

Returns:

  • (String)


7574
7575
7576
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7574

def display_name
  @display_name
end

#machine_findingGoogle::Apis::MigrationcenterV1alpha1::ReportSummaryMachineFinding

A set of findings that applies to assets of type Virtual/Physical Machine. Corresponds to the JSON property machineFinding



7579
7580
7581
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7579

def machine_finding
  @machine_finding
end

#machine_preferencesGoogle::Apis::MigrationcenterV1alpha1::VirtualMachinePreferences

VirtualMachinePreferences enables you to create sets of preferences, for example, a geographical location and pricing track, for your migrated virtual machines. The set of preferences influence recommendations for migrating virtual machine assets. Corresponds to the JSON property machinePreferences



7587
7588
7589
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7587

def machine_preferences
  @machine_preferences
end

#monthly_cost_computeGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostCompute



7592
7593
7594
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7592

def monthly_cost_compute
  @monthly_cost_compute
end

#monthly_cost_database_backupGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostDatabaseBackup



7597
7598
7599
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7597

def monthly_cost_database_backup
  @monthly_cost_database_backup
end

#monthly_cost_database_licensingGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostDatabaseLicensing



7602
7603
7604
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7602

def monthly_cost_database_licensing
  @monthly_cost_database_licensing
end

#monthly_cost_gcve_protectedGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostGcveProtected



7607
7608
7609
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7607

def monthly_cost_gcve_protected
  @monthly_cost_gcve_protected
end

#monthly_cost_network_egressGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostNetworkEgress



7612
7613
7614
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7612

def monthly_cost_network_egress
  @monthly_cost_network_egress
end

#monthly_cost_os_licenseGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostOsLicense



7617
7618
7619
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7617

def monthly_cost_os_license
  @monthly_cost_os_license
end

#monthly_cost_otherGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostOther



7622
7623
7624
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7622

def monthly_cost_other
  @monthly_cost_other
end

#monthly_cost_portable_vmware_licenseGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostPortableVmwareLicense



7627
7628
7629
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7627

def monthly_cost_portable_vmware_license
  @monthly_cost_portable_vmware_license
end

#monthly_cost_storageGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostStorage



7632
7633
7634
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7632

def monthly_cost_storage
  @monthly_cost_storage
end

#monthly_cost_totalGoogle::Apis::MigrationcenterV1alpha1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property monthlyCostTotal



7637
7638
7639
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7637

def monthly_cost_total
  @monthly_cost_total
end

#preference_setGoogle::Apis::MigrationcenterV1alpha1::PreferenceSet

The preferences that apply to all assets in a given context. Corresponds to the JSON property preferenceSet



7642
7643
7644
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7642

def preference_set
  @preference_set
end

#preferred_regionString

Target region for this Preference Set Corresponds to the JSON property preferredRegion

Returns:

  • (String)


7647
7648
7649
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7647

def preferred_region
  @preferred_region
end

#pricing_trackString

Text describing the pricing track specified for this Preference Set Corresponds to the JSON property pricingTrack

Returns:

  • (String)


7652
7653
7654
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7652

def pricing_track
  @pricing_track
end

#sole_tenant_findingGoogle::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantFinding

A set of findings that applies to assets destined for Sole-Tenant nodes. Corresponds to the JSON property soleTenantFinding



7657
7658
7659
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7657

def sole_tenant_finding
  @sole_tenant_finding
end

#top_priorityString

Text describing the business priority specified for this Preference Set Corresponds to the JSON property topPriority

Returns:

  • (String)


7662
7663
7664
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7662

def top_priority
  @top_priority
end

#vmware_engine_findingGoogle::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareEngineFinding

A set of findings that applies to assets destined for VMWare Engine. Corresponds to the JSON property vmwareEngineFinding



7667
7668
7669
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7667

def vmware_engine_finding
  @vmware_engine_finding
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7674
7675
7676
7677
7678
7679
7680
7681
7682
7683
7684
7685
7686
7687
7688
7689
7690
7691
7692
7693
7694
7695
7696
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7674

def update!(**args)
  @database_finding = args[:database_finding] if args.key?(:database_finding)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @machine_finding = args[:machine_finding] if args.key?(:machine_finding)
  @machine_preferences = args[:machine_preferences] if args.key?(:machine_preferences)
  @monthly_cost_compute = args[:monthly_cost_compute] if args.key?(:monthly_cost_compute)
  @monthly_cost_database_backup = args[:monthly_cost_database_backup] if args.key?(:monthly_cost_database_backup)
  @monthly_cost_database_licensing = args[:monthly_cost_database_licensing] if args.key?(:monthly_cost_database_licensing)
  @monthly_cost_gcve_protected = args[:monthly_cost_gcve_protected] if args.key?(:monthly_cost_gcve_protected)
  @monthly_cost_network_egress = args[:monthly_cost_network_egress] if args.key?(:monthly_cost_network_egress)
  @monthly_cost_os_license = args[:monthly_cost_os_license] if args.key?(:monthly_cost_os_license)
  @monthly_cost_other = args[:monthly_cost_other] if args.key?(:monthly_cost_other)
  @monthly_cost_portable_vmware_license = args[:monthly_cost_portable_vmware_license] if args.key?(:monthly_cost_portable_vmware_license)
  @monthly_cost_storage = args[:monthly_cost_storage] if args.key?(:monthly_cost_storage)
  @monthly_cost_total = args[:monthly_cost_total] if args.key?(:monthly_cost_total)
  @preference_set = args[:preference_set] if args.key?(:preference_set)
  @preferred_region = args[:preferred_region] if args.key?(:preferred_region)
  @pricing_track = args[:pricing_track] if args.key?(:pricing_track)
  @sole_tenant_finding = args[:sole_tenant_finding] if args.key?(:sole_tenant_finding)
  @top_priority = args[:top_priority] if args.key?(:top_priority)
  @vmware_engine_finding = args[:vmware_engine_finding] if args.key?(:vmware_engine_finding)
end