Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartData
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A Histogram Chart shows a distribution of values into buckets, showing a count of values which fall into a bucket.
Instance Attribute Summary collapse
-
#buckets ⇒ Array<Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartDataBucket>
Buckets in the histogram.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummaryHistogramChartData
constructor
A new instance of ReportSummaryHistogramChartData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummaryHistogramChartData
Returns a new instance of ReportSummaryHistogramChartData.
7737 7738 7739 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7737 def initialize(**args) update!(**args) end |
Instance Attribute Details
#buckets ⇒ Array<Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartDataBucket>
Buckets in the histogram. There will be n+1 buckets matching n lower
bounds in the request. The first bucket will be from -infinity to the first
bound. Subsequent buckets will be between one bound and the next. The final
bucket will be from the final bound to infinity.
Corresponds to the JSON property buckets
7735 7736 7737 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7735 def buckets @buckets end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7742 7743 7744 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7742 def update!(**args) @buckets = args[:buckets] if args.key?(:buckets) end |