Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartDataBucket
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartDataBucket
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A histogram bucket with a lower and upper bound, and a count of items with a field value between those bounds. The lower bound is inclusive and the upper bound is exclusive. Lower bound may be -infinity and upper bound may be infinity.
Instance Attribute Summary collapse
-
#count ⇒ Fixnum
Count of items in the bucket.
-
#lower_bound ⇒ Fixnum
Lower bound - inclusive.
-
#upper_bound ⇒ Fixnum
Upper bound - exclusive.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummaryHistogramChartDataBucket
constructor
A new instance of ReportSummaryHistogramChartDataBucket.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummaryHistogramChartDataBucket
Returns a new instance of ReportSummaryHistogramChartDataBucket.
7769 7770 7771 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#count ⇒ Fixnum
Count of items in the bucket.
Corresponds to the JSON property count
7757 7758 7759 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7757 def count @count end |
#lower_bound ⇒ Fixnum
Lower bound - inclusive.
Corresponds to the JSON property lowerBound
7762 7763 7764 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7762 def lower_bound @lower_bound end |
#upper_bound ⇒ Fixnum
Upper bound - exclusive.
Corresponds to the JSON property upperBound
7767 7768 7769 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7767 def upper_bound @upper_bound end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7774 7775 7776 7777 7778 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7774 def update!(**args) @count = args[:count] if args.key?(:count) @lower_bound = args[:lower_bound] if args.key?(:lower_bound) @upper_bound = args[:upper_bound] if args.key?(:upper_bound) end |