Class: Google::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantNodeAllocation
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantNodeAllocation
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Represents the assets allocated to a specific Sole-Tenant node type.
Instance Attribute Summary collapse
-
#allocated_asset_count ⇒ Fixnum
Count of assets allocated to these nodes Corresponds to the JSON property
allocatedAssetCount. -
#node ⇒ Google::Apis::MigrationcenterV1alpha1::SoleTenantNodeType
A Sole Tenant node type.
-
#node_count ⇒ Fixnum
Count of this node type to be provisioned Corresponds to the JSON property
nodeCount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummarySoleTenantNodeAllocation
constructor
A new instance of ReportSummarySoleTenantNodeAllocation.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummarySoleTenantNodeAllocation
Returns a new instance of ReportSummarySoleTenantNodeAllocation.
7746 7747 7748 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7746 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_asset_count ⇒ Fixnum
Count of assets allocated to these nodes
Corresponds to the JSON property allocatedAssetCount
7734 7735 7736 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7734 def allocated_asset_count @allocated_asset_count end |
#node ⇒ Google::Apis::MigrationcenterV1alpha1::SoleTenantNodeType
A Sole Tenant node type.
Corresponds to the JSON property node
7739 7740 7741 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7739 def node @node end |
#node_count ⇒ Fixnum
Count of this node type to be provisioned
Corresponds to the JSON property nodeCount
7744 7745 7746 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7744 def node_count @node_count end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7751 7752 7753 7754 7755 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7751 def update!(**args) @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count) @node = args[:node] if args.key?(:node) @node_count = args[:node_count] if args.key?(:node_count) end |