Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareEngineFinding
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareEngineFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A set of findings that applies to assets destined for VMWare Engine.
Instance Attribute Summary collapse
-
#allocated_asset_count ⇒ Fixnum
Count of assets which are allocated Corresponds to the JSON property
allocatedAssetCount. -
#allocated_regions ⇒ Array<String>
Set of regions in which the assets were allocated Corresponds to the JSON property
allocatedRegions. -
#node_allocations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareNodeAllocation>
Set of per-nodetype allocation records Corresponds to the JSON property
nodeAllocations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummaryVmWareEngineFinding
constructor
A new instance of ReportSummaryVmWareEngineFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummaryVmWareEngineFinding
Returns a new instance of ReportSummaryVmWareEngineFinding.
7803 7804 7805 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7803 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_asset_count ⇒ Fixnum
Count of assets which are allocated
Corresponds to the JSON property allocatedAssetCount
7791 7792 7793 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7791 def allocated_asset_count @allocated_asset_count end |
#allocated_regions ⇒ Array<String>
Set of regions in which the assets were allocated
Corresponds to the JSON property allocatedRegions
7796 7797 7798 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7796 def allocated_regions @allocated_regions end |
#node_allocations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareNodeAllocation>
Set of per-nodetype allocation records
Corresponds to the JSON property nodeAllocations
7801 7802 7803 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7801 def node_allocations @node_allocations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7808 7809 7810 7811 7812 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7808 def update!(**args) @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count) @allocated_regions = args[:allocated_regions] if args.key?(:allocated_regions) @node_allocations = args[:node_allocations] if args.key?(:node_allocations) end |