Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareNodeAllocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Represents assets allocated to a specific VMWare Node type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryVmWareNodeAllocation

Returns a new instance of ReportSummaryVmWareNodeAllocation.



8005
8006
8007
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8005

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_asset_countFixnum

Count of assets allocated to these nodes Corresponds to the JSON property allocatedAssetCount

Returns:

  • (Fixnum)


7993
7994
7995
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7993

def allocated_asset_count
  @allocated_asset_count
end

#node_countFixnum

Count of this node type to be provisioned Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


7998
7999
8000
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7998

def node_count
  @node_count
end

#vmware_nodeGoogle::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareNode

A VMWare Engine Node Corresponds to the JSON property vmwareNode



8003
8004
8005
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8003

def vmware_node
  @vmware_node
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8010
8011
8012
8013
8014
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8010

def update!(**args)
  @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count)
  @node_count = args[:node_count] if args.key?(:node_count)
  @vmware_node = args[:vmware_node] if args.key?(:vmware_node)
end