Class: Google::Apis::MigrationcenterV1alpha1::RuntimeNetworkInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Runtime networking information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RuntimeNetworkInfo

Returns a new instance of RuntimeNetworkInfo.



8206
8207
8208
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8206

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#connectionsGoogle::Apis::MigrationcenterV1alpha1::NetworkConnectionList

Network connection list. Corresponds to the JSON property connections



8169
8170
8171
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8169

def connections
  @connections
end

#netstatString

Netstat (raw, OS-agnostic). Corresponds to the JSON property netstat

Returns:

  • (String)


8174
8175
8176
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8174

def netstat
  @netstat
end

#netstat_timeGoogle::Apis::MigrationcenterV1alpha1::DateTime

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations. Corresponds to the JSON property netstatTime



8192
8193
8194
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8192

def netstat_time
  @netstat_time
end

#raw_scan_resultString

Raw network scan result. This field is intended for human inspection. The format of this field may be netstat output or any another raw output. The exact format may change without notice and should not be relied upon. Corresponds to the JSON property rawScanResult

Returns:

  • (String)


8199
8200
8201
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8199

def raw_scan_result
  @raw_scan_result
end

#scan_timeString

Time of the last network scan. Corresponds to the JSON property scanTime

Returns:

  • (String)


8204
8205
8206
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8204

def scan_time
  @scan_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8211
8212
8213
8214
8215
8216
8217
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8211

def update!(**args)
  @connections = args[:connections] if args.key?(:connections)
  @netstat = args[:netstat] if args.key?(:netstat)
  @netstat_time = args[:netstat_time] if args.key?(:netstat_time)
  @raw_scan_result = args[:raw_scan_result] if args.key?(:raw_scan_result)
  @scan_time = args[:scan_time] if args.key?(:scan_time)
end