Class: Google::Apis::MigrationcenterV1alpha1::Settings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Describes the Migration Center settings related to the project.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Settings

Returns a new instance of Settings.



8449
8450
8451
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8449

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Customer consent for Google sales to access their Cloud Migration Center project. Corresponds to the JSON property customerConsentForGoogleSalesToAccessMigrationCenter

Returns:

  • (Boolean)


8429
8430
8431
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8429

def customer_consent_for_google_sales_to_access_migration_center
  @customer_consent_for_google_sales_to_access_migration_center
end

#disable_cloud_loggingBoolean Also known as: disable_cloud_logging?

Disable Cloud Logging for the Migration Center API. Users are billed for the logs. Corresponds to the JSON property disableCloudLogging

Returns:

  • (Boolean)


8436
8437
8438
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8436

def disable_cloud_logging
  @disable_cloud_logging
end

#nameString

Output only. The name of the resource. Corresponds to the JSON property name

Returns:

  • (String)


8442
8443
8444
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8442

def name
  @name
end

#preference_setString

The preference set used by default for a project. Corresponds to the JSON property preferenceSet

Returns:

  • (String)


8447
8448
8449
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8447

def preference_set
  @preference_set
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8454
8455
8456
8457
8458
8459
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8454

def update!(**args)
  @customer_consent_for_google_sales_to_access_migration_center = args[:customer_consent_for_google_sales_to_access_migration_center] if args.key?(:customer_consent_for_google_sales_to_access_migration_center)
  @disable_cloud_logging = args[:disable_cloud_logging] if args.key?(:disable_cloud_logging)
  @name = args[:name] if args.key?(:name)
  @preference_set = args[:preference_set] if args.key?(:preference_set)
end