Class: Google::Apis::MigrationcenterV1alpha1::SoleTenancyPreferences
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::SoleTenancyPreferences
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Preferences concerning Sole Tenancy nodes and VMs.
Instance Attribute Summary collapse
-
#commitment_plan ⇒ String
Commitment plan to consider when calculating costs for virtual machine insights and recommendations.
-
#cpu_overcommit_ratio ⇒ Float
CPU overcommit ratio.
-
#host_maintenance_policy ⇒ String
Sole Tenancy nodes maintenance policy.
-
#node_types ⇒ Array<Google::Apis::MigrationcenterV1alpha1::SoleTenantNodeType>
A list of sole tenant node types.
-
#os_pricing_preferences ⇒ Google::Apis::MigrationcenterV1alpha1::OperatingSystemPricingPreferences
Pricing options for OS images.
Instance Method Summary collapse
-
#initialize(**args) ⇒ SoleTenancyPreferences
constructor
A new instance of SoleTenancyPreferences.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ SoleTenancyPreferences
Returns a new instance of SoleTenancyPreferences.
8576 8577 8578 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8576 def initialize(**args) update!(**args) end |
Instance Attribute Details
#commitment_plan ⇒ String
Commitment plan to consider when calculating costs for virtual machine
insights and recommendations. If you are unsure which value to set, a 3 year
commitment plan is often a good value to start with.
Corresponds to the JSON property commitmentPlan
8553 8554 8555 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8553 def commitment_plan @commitment_plan end |
#cpu_overcommit_ratio ⇒ Float
CPU overcommit ratio. Acceptable values are between 1.0 and 2.0 inclusive.
Corresponds to the JSON property cpuOvercommitRatio
8558 8559 8560 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8558 def cpu_overcommit_ratio @cpu_overcommit_ratio end |
#host_maintenance_policy ⇒ String
Sole Tenancy nodes maintenance policy.
Corresponds to the JSON property hostMaintenancePolicy
8563 8564 8565 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8563 def host_maintenance_policy @host_maintenance_policy end |
#node_types ⇒ Array<Google::Apis::MigrationcenterV1alpha1::SoleTenantNodeType>
A list of sole tenant node types. An empty list means that all possible node
types will be considered.
Corresponds to the JSON property nodeTypes
8569 8570 8571 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8569 def node_types @node_types end |
#os_pricing_preferences ⇒ Google::Apis::MigrationcenterV1alpha1::OperatingSystemPricingPreferences
Pricing options for OS images.
Corresponds to the JSON property osPricingPreferences
8574 8575 8576 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8574 def os_pricing_preferences @os_pricing_preferences end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8581 8582 8583 8584 8585 8586 8587 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8581 def update!(**args) @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan) @cpu_overcommit_ratio = args[:cpu_overcommit_ratio] if args.key?(:cpu_overcommit_ratio) @host_maintenance_policy = args[:host_maintenance_policy] if args.key?(:host_maintenance_policy) @node_types = args[:node_types] if args.key?(:node_types) @os_pricing_preferences = args[:os_pricing_preferences] if args.key?(:os_pricing_preferences) end |