Class: Google::Apis::MigrationcenterV1alpha1::Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Source represents an object from which asset information is streamed to Migration Center.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



8673
8674
8675
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8673

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the source was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8618
8619
8620
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8618

def create_time
  @create_time
end

#descriptionString

Free-text description. Corresponds to the JSON property description

Returns:

  • (String)


8623
8624
8625
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8623

def description
  @description
end

#display_nameString

User-friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


8628
8629
8630
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8628

def display_name
  @display_name
end

#error_frame_countFixnum

Output only. The number of frames that were reported by the source and contained errors. Corresponds to the JSON property errorFrameCount

Returns:

  • (Fixnum)


8634
8635
8636
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8634

def error_frame_count
  @error_frame_count
end

#is_managedBoolean Also known as: is_managed?

If true, the source is managed by other service(s). Corresponds to the JSON property isManaged

Returns:

  • (Boolean)


8639
8640
8641
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8639

def is_managed
  @is_managed
end

#nameString

Output only. The full name of the source. Corresponds to the JSON property name

Returns:

  • (String)


8645
8646
8647
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8645

def name
  @name
end

#pending_frame_countFixnum

Output only. Number of frames that are still being processed. Corresponds to the JSON property pendingFrameCount

Returns:

  • (Fixnum)


8650
8651
8652
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8650

def pending_frame_count
  @pending_frame_count
end

#priorityFixnum

The information confidence of the source. The higher the value, the higher the confidence. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


8656
8657
8658
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8656

def priority
  @priority
end

#stateString

Output only. The state of the source. Corresponds to the JSON property state

Returns:

  • (String)


8661
8662
8663
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8661

def state
  @state
end

#typeString

Data source type. Corresponds to the JSON property type

Returns:

  • (String)


8666
8667
8668
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8666

def type
  @type
end

#update_timeString

Output only. The timestamp when the source was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8671
8672
8673
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8671

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8678
8679
8680
8681
8682
8683
8684
8685
8686
8687
8688
8689
8690
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8678

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error_frame_count = args[:error_frame_count] if args.key?(:error_frame_count)
  @is_managed = args[:is_managed] if args.key?(:is_managed)
  @name = args[:name] if args.key?(:name)
  @pending_frame_count = args[:pending_frame_count] if args.key?(:pending_frame_count)
  @priority = args[:priority] if args.key?(:priority)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end