Class: Google::Apis::MigrationcenterV1alpha1::UploadFileInfo
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::UploadFileInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A resource that contains a URI to which a data file can be uploaded.
Instance Attribute Summary collapse
-
#headers ⇒ Hash<String,String>
Output only.
-
#signed_uri ⇒ String
Output only.
-
#uri_expiration_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadFileInfo
constructor
A new instance of UploadFileInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadFileInfo
Returns a new instance of UploadFileInfo.
8956 8957 8958 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8956 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Hash<String,String>
Output only. The headers that were used to sign the URL.
Corresponds to the JSON property headers
8944 8945 8946 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8944 def headers @headers end |
#signed_uri ⇒ String
Output only. Upload URI for the file.
Corresponds to the JSON property signedUri
8949 8950 8951 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8949 def signed_uri @signed_uri end |
#uri_expiration_time ⇒ String
Output only. Expiration time of the upload URI.
Corresponds to the JSON property uriExpirationTime
8954 8955 8956 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8954 def uri_expiration_time @uri_expiration_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8961 8962 8963 8964 8965 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8961 def update!(**args) @headers = args[:headers] if args.key?(:headers) @signed_uri = args[:signed_uri] if args.key?(:signed_uri) @uri_expiration_time = args[:uri_expiration_time] if args.key?(:uri_expiration_time) end |