Class: Google::Apis::MigrationcenterV1alpha1::VirtualMachinePreferencesSizingOptimizationCustomParameters

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Custom data to use for sizing optimizations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VirtualMachinePreferencesSizingOptimizationCustomParameters

Returns a new instance of VirtualMachinePreferencesSizingOptimizationCustomParameters.



9456
9457
9458
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#aggregation_methodString

Optional. Type of statistical aggregation of a resource utilization data, on which to base the sizing metrics. Corresponds to the JSON property aggregationMethod

Returns:

  • (String)


9436
9437
9438
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9436

def aggregation_method
  @aggregation_method
end

#cpu_usage_percentageFixnum

Optional. Desired percentage of CPU usage. Must be in the interval 1, 100. Corresponds to the JSON property cpuUsagePercentage

Returns:

  • (Fixnum)


9442
9443
9444
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9442

def cpu_usage_percentage
  @cpu_usage_percentage
end

#memory_usage_percentageFixnum

Optional. Desired percentage of memory usage. Must be in the interval 1, 100. Corresponds to the JSON property memoryUsagePercentage

Returns:

  • (Fixnum)


9448
9449
9450
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9448

def memory_usage_percentage
  @memory_usage_percentage
end

#storage_multiplierFloat

Optional. Desired increase factor of storage, relative to currently used storage. Must be in the interval 1.0, 2.0. Corresponds to the JSON property storageMultiplier

Returns:

  • (Float)


9454
9455
9456
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9454

def storage_multiplier
  @storage_multiplier
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9461
9462
9463
9464
9465
9466
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9461

def update!(**args)
  @aggregation_method = args[:aggregation_method] if args.key?(:aggregation_method)
  @cpu_usage_percentage = args[:cpu_usage_percentage] if args.key?(:cpu_usage_percentage)
  @memory_usage_percentage = args[:memory_usage_percentage] if args.key?(:memory_usage_percentage)
  @storage_multiplier = args[:storage_multiplier] if args.key?(:storage_multiplier)
end