Class: Google::Apis::MigrationcenterV1alpha1::Asset

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

An asset represents a resource in your environment. Asset types include virtual machines and databases.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Asset

Returns a new instance of Asset.



601
602
603
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 601

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#assigned_groupsArray<String>

Output only. The list of groups that the asset is assigned to. Corresponds to the JSON property assignedGroups

Returns:

  • (Array<String>)


393
394
395
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 393

def assigned_groups
  @assigned_groups
end

#attributesHash<String,String>

Generic asset attributes. Corresponds to the JSON property attributes

Returns:

  • (Hash<String,String>)


398
399
400
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 398

def attributes
  @attributes
end

#aws_api_gateway_rest_api_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsApiGatewayRestApiDetails

Asset information specific for AWS API Gateway REST APIs. Corresponds to the JSON property awsApiGatewayRestApiDetails



403
404
405
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 403

def aws_api_gateway_rest_api_details
  @aws_api_gateway_rest_api_details
end

#aws_app_sync_graphql_api_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsAppSyncGraphqlApiDetails

Asset information specific for AWS AppSync GraphQL APIs. Corresponds to the JSON property awsAppSyncGraphqlApiDetails



408
409
410
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 408

def aws_app_sync_graphql_api_details
  @aws_app_sync_graphql_api_details
end

#aws_application_load_balancer_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsApplicationLoadBalancerDetails

Asset information specific for AWS Application Load Balancers. Corresponds to the JSON property awsApplicationLoadBalancerDetails



413
414
415
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 413

def aws_application_load_balancer_details
  @aws_application_load_balancer_details
end

#aws_autoscaling_group_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsAutoscalingGroupDetails

Asset information specific for AWS Autoscaling Group. Corresponds to the JSON property awsAutoscalingGroupDetails



418
419
420
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 418

def aws_autoscaling_group_details
  @aws_autoscaling_group_details
end

#aws_batch_compute_environment_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsBatchComputeEnvironmentDetails

Asset information specific for AWS Batch Compute Environments. Corresponds to the JSON property awsBatchComputeEnvironmentDetails



423
424
425
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 423

def aws_batch_compute_environment_details
  @aws_batch_compute_environment_details
end

#aws_cloud_front_distribution_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsCloudFrontDistributionDetails

Details of an AWS CloudFront distribution. Corresponds to the JSON property awsCloudFrontDistributionDetails



428
429
430
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 428

def aws_cloud_front_distribution_details
  @aws_cloud_front_distribution_details
end

#aws_dynamodb_table_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsDynamoDbTableDetails

Details of an AWS DynamoDB table. Corresponds to the JSON property awsDynamodbTableDetails



433
434
435
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 433

def aws_dynamodb_table_details
  @aws_dynamodb_table_details
end

#aws_ebs_volume_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEbsVolumeDetails

Asset information specific for AWS EBS Volumes. Corresponds to the JSON property awsEbsVolumeDetails



438
439
440
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 438

def aws_ebs_volume_details
  @aws_ebs_volume_details
end

#aws_ecr_repository_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEcrRepositoryDetails

Asset information specific for AWS ECR Repository. Corresponds to the JSON property awsEcrRepositoryDetails



443
444
445
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 443

def aws_ecr_repository_details
  @aws_ecr_repository_details
end

#aws_ecs_cluster_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEcsClusterDetails

Details of an AWS ECS cluster. Corresponds to the JSON property awsEcsClusterDetails



448
449
450
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 448

def aws_ecs_cluster_details
  @aws_ecs_cluster_details
end

#aws_efs_file_system_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEfsFileSystemDetails

Details of an AWS EFS file system. Corresponds to the JSON property awsEfsFileSystemDetails



453
454
455
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 453

def aws_efs_file_system_details
  @aws_efs_file_system_details
end

#aws_eks_cluster_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsEksClusterDetails

Asset information specific for AWS EKS clusters. Corresponds to the JSON property awsEksClusterDetails



458
459
460
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 458

def aws_eks_cluster_details
  @aws_eks_cluster_details
end

#aws_elastic_ip_address_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElasticIpAddressDetails

Asset information specific for AWS Elastic IP Addresses. Corresponds to the JSON property awsElasticIpAddressDetails



463
464
465
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 463

def aws_elastic_ip_address_details
  @aws_elastic_ip_address_details
end

#aws_elastic_network_interface_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElasticNetworkInterfaceDetails

Asset information specific for AWS Elastic Network Interfaces. Corresponds to the JSON property awsElasticNetworkInterfaceDetails



468
469
470
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 468

def aws_elastic_network_interface_details
  @aws_elastic_network_interface_details
end

#aws_elb_load_balancer_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsElbLoadBalancerDetails

Asset information specific for AWS Load Balancers. Corresponds to the JSON property awsElbLoadBalancerDetails



473
474
475
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 473

def aws_elb_load_balancer_details
  @aws_elb_load_balancer_details
end

#aws_internet_gateway_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsInternetGatewayDetails

Asset information specific for AWS Internet Gateways. Corresponds to the JSON property awsInternetGatewayDetails



478
479
480
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 478

def aws_internet_gateway_details
  @aws_internet_gateway_details
end

#aws_lambda_function_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsLambdaFunctionDetails

Asset information specific for AWS Lambda functions. Corresponds to the JSON property awsLambdaFunctionDetails



483
484
485
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 483

def aws_lambda_function_details
  @aws_lambda_function_details
end

#aws_nat_gateway_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsNatGatewayDetails

Details of an AWS NAT Gateway. Corresponds to the JSON property awsNatGatewayDetails



488
489
490
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 488

def aws_nat_gateway_details
  @aws_nat_gateway_details
end

#aws_redshift_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsRedshiftDetails

Details of an AWS Redshift cluster. Corresponds to the JSON property awsRedshiftDetails



493
494
495
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 493

def aws_redshift_details
  @aws_redshift_details
end

#aws_route53_hosted_zone_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsRoute53HostedZoneDetails

Details of an AWS Route 53 Hosted Zone. Corresponds to the JSON property awsRoute53HostedZoneDetails



498
499
500
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 498

def aws_route53_hosted_zone_details
  @aws_route53_hosted_zone_details
end

#aws_s3_bucket_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsS3BucketDetails

Asset information specific for AWS S3 buckets. Corresponds to the JSON property awsS3BucketDetails



503
504
505
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 503

def aws_s3_bucket_details
  @aws_s3_bucket_details
end

#aws_sns_topic_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsSnsTopicDetails

Asset information specific for AWS SNS Topics. Corresponds to the JSON property awsSnsTopicDetails



508
509
510
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 508

def aws_sns_topic_details
  @aws_sns_topic_details
end

#aws_vpc_detailsGoogle::Apis::MigrationcenterV1alpha1::AwsVpcDetails

Asset information specific for AWS VPCs. Corresponds to the JSON property awsVpcDetails



513
514
515
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 513

def aws_vpc_details
  @aws_vpc_details
end

#create_timeString

Output only. The timestamp when the asset was created. Corresponds to the JSON property createTime

Returns:

  • (String)


518
519
520
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 518

def create_time
  @create_time
end

#database_deployment_detailsGoogle::Apis::MigrationcenterV1alpha1::DatabaseDeploymentDetails

The details of a database deployment asset. Corresponds to the JSON property databaseDeploymentDetails



523
524
525
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 523

def database_deployment_details
  @database_deployment_details
end

#database_detailsGoogle::Apis::MigrationcenterV1alpha1::DatabaseDetails

Details of a logical database. Corresponds to the JSON property databaseDetails



528
529
530
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 528

def database_details
  @database_details
end

#hiddenBoolean Also known as: hidden?

Optional. Indicates if the asset is hidden. Corresponds to the JSON property hidden

Returns:

  • (Boolean)


533
534
535
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 533

def hidden
  @hidden
end

#hide_reasonString

Optional. An optional reason for marking this asset as hidden. Corresponds to the JSON property hideReason

Returns:

  • (String)


539
540
541
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 539

def hide_reason
  @hide_reason
end

#hide_timeString

Output only. The timestamp when the asset was marked as hidden. Corresponds to the JSON property hideTime

Returns:

  • (String)


544
545
546
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 544

def hide_time
  @hide_time
end

#hosting_provider_detailsGoogle::Apis::MigrationcenterV1alpha1::HostingProviderDetails

Details about the hosting platform of the asset. Corresponds to the JSON property hostingProviderDetails



549
550
551
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 549

def hosting_provider_details
  @hosting_provider_details
end

#insight_listGoogle::Apis::MigrationcenterV1alpha1::InsightList

Message containing insights list. Corresponds to the JSON property insightList



554
555
556
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 554

def insight_list
  @insight_list
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


559
560
561
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 559

def labels
  @labels
end

#machine_detailsGoogle::Apis::MigrationcenterV1alpha1::MachineDetails

Details of a machine. Corresponds to the JSON property machineDetails



564
565
566
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 564

def machine_details
  @machine_details
end

#nameString

Output only. The full name of the asset. Corresponds to the JSON property name

Returns:

  • (String)


569
570
571
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 569

def name
  @name
end

#performance_dataGoogle::Apis::MigrationcenterV1alpha1::AssetPerformanceData

Performance data for an asset. Corresponds to the JSON property performanceData



574
575
576
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 574

def performance_data
  @performance_data
end

#sourcesArray<String>

Output only. The list of sources contributing to the asset. Corresponds to the JSON property sources

Returns:

  • (Array<String>)


579
580
581
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 579

def sources
  @sources
end

#structured_attributesHash<String,Object>

Optional. Generic structured asset attributes. Corresponds to the JSON property structuredAttributes

Returns:

  • (Hash<String,Object>)


584
585
586
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 584

def structured_attributes
  @structured_attributes
end

#titleString

Output only. Server generated human readable name of the asset. Corresponds to the JSON property title

Returns:

  • (String)


589
590
591
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 589

def title
  @title
end

#update_timeString

Output only. The timestamp when the asset was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


594
595
596
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 594

def update_time
  @update_time
end

#virtual_machine_detailsGoogle::Apis::MigrationcenterV1alpha1::VirtualMachineDetails

Details of a VirtualMachine. Corresponds to the JSON property virtualMachineDetails



599
600
601
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 599

def virtual_machine_details
  @virtual_machine_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 606

def update!(**args)
  @assigned_groups = args[:assigned_groups] if args.key?(:assigned_groups)
  @attributes = args[:attributes] if args.key?(:attributes)
  @aws_api_gateway_rest_api_details = args[:aws_api_gateway_rest_api_details] if args.key?(:aws_api_gateway_rest_api_details)
  @aws_app_sync_graphql_api_details = args[:aws_app_sync_graphql_api_details] if args.key?(:aws_app_sync_graphql_api_details)
  @aws_application_load_balancer_details = args[:aws_application_load_balancer_details] if args.key?(:aws_application_load_balancer_details)
  @aws_autoscaling_group_details = args[:aws_autoscaling_group_details] if args.key?(:aws_autoscaling_group_details)
  @aws_batch_compute_environment_details = args[:aws_batch_compute_environment_details] if args.key?(:aws_batch_compute_environment_details)
  @aws_cloud_front_distribution_details = args[:aws_cloud_front_distribution_details] if args.key?(:aws_cloud_front_distribution_details)
  @aws_dynamodb_table_details = args[:aws_dynamodb_table_details] if args.key?(:aws_dynamodb_table_details)
  @aws_ebs_volume_details = args[:aws_ebs_volume_details] if args.key?(:aws_ebs_volume_details)
  @aws_ecr_repository_details = args[:aws_ecr_repository_details] if args.key?(:aws_ecr_repository_details)
  @aws_ecs_cluster_details = args[:aws_ecs_cluster_details] if args.key?(:aws_ecs_cluster_details)
  @aws_efs_file_system_details = args[:aws_efs_file_system_details] if args.key?(:aws_efs_file_system_details)
  @aws_eks_cluster_details = args[:aws_eks_cluster_details] if args.key?(:aws_eks_cluster_details)
  @aws_elastic_ip_address_details = args[:aws_elastic_ip_address_details] if args.key?(:aws_elastic_ip_address_details)
  @aws_elastic_network_interface_details = args[:aws_elastic_network_interface_details] if args.key?(:aws_elastic_network_interface_details)
  @aws_elb_load_balancer_details = args[:aws_elb_load_balancer_details] if args.key?(:aws_elb_load_balancer_details)
  @aws_internet_gateway_details = args[:aws_internet_gateway_details] if args.key?(:aws_internet_gateway_details)
  @aws_lambda_function_details = args[:aws_lambda_function_details] if args.key?(:aws_lambda_function_details)
  @aws_nat_gateway_details = args[:aws_nat_gateway_details] if args.key?(:aws_nat_gateway_details)
  @aws_redshift_details = args[:aws_redshift_details] if args.key?(:aws_redshift_details)
  @aws_route53_hosted_zone_details = args[:aws_route53_hosted_zone_details] if args.key?(:aws_route53_hosted_zone_details)
  @aws_s3_bucket_details = args[:aws_s3_bucket_details] if args.key?(:aws_s3_bucket_details)
  @aws_sns_topic_details = args[:aws_sns_topic_details] if args.key?(:aws_sns_topic_details)
  @aws_vpc_details = args[:aws_vpc_details] if args.key?(:aws_vpc_details)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_deployment_details = args[:database_deployment_details] if args.key?(:database_deployment_details)
  @database_details = args[:database_details] if args.key?(:database_details)
  @hidden = args[:hidden] if args.key?(:hidden)
  @hide_reason = args[:hide_reason] if args.key?(:hide_reason)
  @hide_time = args[:hide_time] if args.key?(:hide_time)
  @hosting_provider_details = args[:hosting_provider_details] if args.key?(:hosting_provider_details)
  @insight_list = args[:insight_list] if args.key?(:insight_list)
  @labels = args[:labels] if args.key?(:labels)
  @machine_details = args[:machine_details] if args.key?(:machine_details)
  @name = args[:name] if args.key?(:name)
  @performance_data = args[:performance_data] if args.key?(:performance_data)
  @sources = args[:sources] if args.key?(:sources)
  @structured_attributes = args[:structured_attributes] if args.key?(:structured_attributes)
  @title = args[:title] if args.key?(:title)
  @update_time = args[:update_time] if args.key?(:update_time)
  @virtual_machine_details = args[:virtual_machine_details] if args.key?(:virtual_machine_details)
end