Class: Google::Apis::MigrationcenterV1alpha1::AssetFrame
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::AssetFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Contains data reported from an inventory source on an asset.
Instance Attribute Summary collapse
-
#attributes ⇒ Hash<String,String>
Generic asset attributes.
-
#aws_api_gateway_rest_api_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsApiGatewayRestApiDetails
Asset information specific for AWS API Gateway REST APIs.
-
#aws_app_sync_graphql_api_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsAppSyncGraphqlApiDetails
Asset information specific for AWS AppSync GraphQL APIs.
-
#aws_application_load_balancer_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsApplicationLoadBalancerDetails
Asset information specific for AWS Application Load Balancers.
-
#aws_autoscaling_group_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsAutoscalingGroupDetails
Asset information specific for AWS Autoscaling Group.
-
#aws_batch_compute_environment_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsBatchComputeEnvironmentDetails
Asset information specific for AWS Batch Compute Environments.
-
#aws_cloud_front_distribution_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsCloudFrontDistributionDetails
Details of an AWS CloudFront distribution.
-
#aws_dynamodb_table_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsDynamoDbTableDetails
Details of an AWS DynamoDB table.
-
#aws_ebs_volume_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEbsVolumeDetails
Asset information specific for AWS EBS Volumes.
-
#aws_ecr_repository_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEcrRepositoryDetails
Asset information specific for AWS ECR Repository.
-
#aws_ecs_cluster_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEcsClusterDetails
Details of an AWS ECS cluster.
-
#aws_efs_file_system_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEfsFileSystemDetails
Details of an AWS EFS file system.
-
#aws_eks_cluster_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEksClusterDetails
Asset information specific for AWS EKS clusters.
-
#aws_elastic_ip_address_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsElasticIpAddressDetails
Asset information specific for AWS Elastic IP Addresses.
-
#aws_elastic_network_interface_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsElasticNetworkInterfaceDetails
Asset information specific for AWS Elastic Network Interfaces.
-
#aws_elb_load_balancer_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsElbLoadBalancerDetails
Asset information specific for AWS Load Balancers.
-
#aws_internet_gateway_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsInternetGatewayDetails
Asset information specific for AWS Internet Gateways.
-
#aws_lambda_function_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsLambdaFunctionDetails
Asset information specific for AWS Lambda functions.
-
#aws_nat_gateway_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsNatGatewayDetails
Details of an AWS NAT Gateway.
-
#aws_redshift_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsRedshiftDetails
Details of an AWS Redshift cluster.
-
#aws_route53_hosted_zone_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsRoute53HostedZoneDetails
Details of an AWS Route 53 Hosted Zone.
-
#aws_s3_bucket_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsS3BucketDetails
Asset information specific for AWS S3 buckets.
-
#aws_sns_topic_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsSnsTopicDetails
Asset information specific for AWS SNS Topics.
-
#aws_vpc_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsVpcDetails
Asset information specific for AWS VPCs.
-
#collection_type ⇒ String
Optional.
-
#database_deployment_details ⇒ Google::Apis::MigrationcenterV1alpha1::DatabaseDeploymentDetails
The details of a database deployment asset.
-
#database_details ⇒ Google::Apis::MigrationcenterV1alpha1::DatabaseDetails
Details of a logical database.
-
#hosting_provider_details ⇒ Google::Apis::MigrationcenterV1alpha1::HostingProviderDetails
Details about the hosting platform of the asset.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs.
-
#machine_details ⇒ Google::Apis::MigrationcenterV1alpha1::MachineDetails
Details of a machine.
-
#performance_samples ⇒ Array<Google::Apis::MigrationcenterV1alpha1::PerformanceSample>
Asset performance data samples.
-
#report_time ⇒ String
The time the data was reported.
-
#structured_attributes ⇒ Hash<String,Object>
Optional.
-
#trace_token ⇒ String
Optional.
-
#virtual_machine_details ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineDetails
Details of a VirtualMachine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssetFrame
constructor
A new instance of AssetFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssetFrame
Returns a new instance of AssetFrame.
834 835 836 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 834 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attributes ⇒ Hash<String,String>
Generic asset attributes.
Corresponds to the JSON property attributes
659 660 661 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 659 def attributes @attributes end |
#aws_api_gateway_rest_api_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsApiGatewayRestApiDetails
Asset information specific for AWS API Gateway REST APIs.
Corresponds to the JSON property awsApiGatewayRestApiDetails
664 665 666 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 664 def aws_api_gateway_rest_api_details @aws_api_gateway_rest_api_details end |
#aws_app_sync_graphql_api_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsAppSyncGraphqlApiDetails
Asset information specific for AWS AppSync GraphQL APIs.
Corresponds to the JSON property awsAppSyncGraphqlApiDetails
669 670 671 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 669 def aws_app_sync_graphql_api_details @aws_app_sync_graphql_api_details end |
#aws_application_load_balancer_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsApplicationLoadBalancerDetails
Asset information specific for AWS Application Load Balancers.
Corresponds to the JSON property awsApplicationLoadBalancerDetails
674 675 676 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 674 def aws_application_load_balancer_details @aws_application_load_balancer_details end |
#aws_autoscaling_group_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsAutoscalingGroupDetails
Asset information specific for AWS Autoscaling Group.
Corresponds to the JSON property awsAutoscalingGroupDetails
679 680 681 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 679 def aws_autoscaling_group_details @aws_autoscaling_group_details end |
#aws_batch_compute_environment_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsBatchComputeEnvironmentDetails
Asset information specific for AWS Batch Compute Environments.
Corresponds to the JSON property awsBatchComputeEnvironmentDetails
684 685 686 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 684 def aws_batch_compute_environment_details @aws_batch_compute_environment_details end |
#aws_cloud_front_distribution_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsCloudFrontDistributionDetails
Details of an AWS CloudFront distribution.
Corresponds to the JSON property awsCloudFrontDistributionDetails
689 690 691 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 689 def aws_cloud_front_distribution_details @aws_cloud_front_distribution_details end |
#aws_dynamodb_table_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsDynamoDbTableDetails
Details of an AWS DynamoDB table.
Corresponds to the JSON property awsDynamodbTableDetails
694 695 696 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 694 def aws_dynamodb_table_details @aws_dynamodb_table_details end |
#aws_ebs_volume_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEbsVolumeDetails
Asset information specific for AWS EBS Volumes.
Corresponds to the JSON property awsEbsVolumeDetails
699 700 701 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 699 def aws_ebs_volume_details @aws_ebs_volume_details end |
#aws_ecr_repository_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEcrRepositoryDetails
Asset information specific for AWS ECR Repository.
Corresponds to the JSON property awsEcrRepositoryDetails
704 705 706 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 704 def aws_ecr_repository_details @aws_ecr_repository_details end |
#aws_ecs_cluster_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEcsClusterDetails
Details of an AWS ECS cluster.
Corresponds to the JSON property awsEcsClusterDetails
709 710 711 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 709 def aws_ecs_cluster_details @aws_ecs_cluster_details end |
#aws_efs_file_system_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEfsFileSystemDetails
Details of an AWS EFS file system.
Corresponds to the JSON property awsEfsFileSystemDetails
714 715 716 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 714 def aws_efs_file_system_details @aws_efs_file_system_details end |
#aws_eks_cluster_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsEksClusterDetails
Asset information specific for AWS EKS clusters.
Corresponds to the JSON property awsEksClusterDetails
719 720 721 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 719 def aws_eks_cluster_details @aws_eks_cluster_details end |
#aws_elastic_ip_address_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsElasticIpAddressDetails
Asset information specific for AWS Elastic IP Addresses.
Corresponds to the JSON property awsElasticIpAddressDetails
724 725 726 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 724 def aws_elastic_ip_address_details @aws_elastic_ip_address_details end |
#aws_elastic_network_interface_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsElasticNetworkInterfaceDetails
Asset information specific for AWS Elastic Network Interfaces.
Corresponds to the JSON property awsElasticNetworkInterfaceDetails
729 730 731 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 729 def aws_elastic_network_interface_details @aws_elastic_network_interface_details end |
#aws_elb_load_balancer_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsElbLoadBalancerDetails
Asset information specific for AWS Load Balancers.
Corresponds to the JSON property awsElbLoadBalancerDetails
734 735 736 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 734 def aws_elb_load_balancer_details @aws_elb_load_balancer_details end |
#aws_internet_gateway_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsInternetGatewayDetails
Asset information specific for AWS Internet Gateways.
Corresponds to the JSON property awsInternetGatewayDetails
739 740 741 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 739 def aws_internet_gateway_details @aws_internet_gateway_details end |
#aws_lambda_function_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsLambdaFunctionDetails
Asset information specific for AWS Lambda functions.
Corresponds to the JSON property awsLambdaFunctionDetails
744 745 746 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 744 def aws_lambda_function_details @aws_lambda_function_details end |
#aws_nat_gateway_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsNatGatewayDetails
Details of an AWS NAT Gateway.
Corresponds to the JSON property awsNatGatewayDetails
749 750 751 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 749 def aws_nat_gateway_details @aws_nat_gateway_details end |
#aws_redshift_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsRedshiftDetails
Details of an AWS Redshift cluster.
Corresponds to the JSON property awsRedshiftDetails
754 755 756 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 754 def aws_redshift_details @aws_redshift_details end |
#aws_route53_hosted_zone_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsRoute53HostedZoneDetails
Details of an AWS Route 53 Hosted Zone.
Corresponds to the JSON property awsRoute53HostedZoneDetails
759 760 761 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 759 def aws_route53_hosted_zone_details @aws_route53_hosted_zone_details end |
#aws_s3_bucket_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsS3BucketDetails
Asset information specific for AWS S3 buckets.
Corresponds to the JSON property awsS3BucketDetails
764 765 766 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 764 def aws_s3_bucket_details @aws_s3_bucket_details end |
#aws_sns_topic_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsSnsTopicDetails
Asset information specific for AWS SNS Topics.
Corresponds to the JSON property awsSnsTopicDetails
769 770 771 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 769 def aws_sns_topic_details @aws_sns_topic_details end |
#aws_vpc_details ⇒ Google::Apis::MigrationcenterV1alpha1::AwsVpcDetails
Asset information specific for AWS VPCs.
Corresponds to the JSON property awsVpcDetails
774 775 776 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 774 def aws_vpc_details @aws_vpc_details end |
#collection_type ⇒ String
Optional. Frame collection type, if not specified the collection type will be
based on the source type of the source the frame was reported on.
Corresponds to the JSON property collectionType
780 781 782 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 780 def collection_type @collection_type end |
#database_deployment_details ⇒ Google::Apis::MigrationcenterV1alpha1::DatabaseDeploymentDetails
The details of a database deployment asset.
Corresponds to the JSON property databaseDeploymentDetails
785 786 787 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 785 def database_deployment_details @database_deployment_details end |
#database_details ⇒ Google::Apis::MigrationcenterV1alpha1::DatabaseDetails
Details of a logical database.
Corresponds to the JSON property databaseDetails
790 791 792 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 790 def database_details @database_details end |
#hosting_provider_details ⇒ Google::Apis::MigrationcenterV1alpha1::HostingProviderDetails
Details about the hosting platform of the asset.
Corresponds to the JSON property hostingProviderDetails
795 796 797 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 795 def hosting_provider_details @hosting_provider_details end |
#labels ⇒ Hash<String,String>
Labels as key value pairs.
Corresponds to the JSON property labels
800 801 802 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 800 def labels @labels end |
#machine_details ⇒ Google::Apis::MigrationcenterV1alpha1::MachineDetails
Details of a machine.
Corresponds to the JSON property machineDetails
805 806 807 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 805 def machine_details @machine_details end |
#performance_samples ⇒ Array<Google::Apis::MigrationcenterV1alpha1::PerformanceSample>
Asset performance data samples. Samples that are from more than 40 days ago or
after tomorrow are ignored.
Corresponds to the JSON property performanceSamples
811 812 813 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 811 def performance_samples @performance_samples end |
#report_time ⇒ String
The time the data was reported.
Corresponds to the JSON property reportTime
816 817 818 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 816 def report_time @report_time end |
#structured_attributes ⇒ Hash<String,Object>
Optional. Generic structured asset attributes.
Corresponds to the JSON property structuredAttributes
821 822 823 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 821 def structured_attributes @structured_attributes end |
#trace_token ⇒ String
Optional. Trace token is optionally provided to assist with debugging and
traceability.
Corresponds to the JSON property traceToken
827 828 829 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 827 def trace_token @trace_token end |
#virtual_machine_details ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineDetails
Details of a VirtualMachine.
Corresponds to the JSON property virtualMachineDetails
832 833 834 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 832 def virtual_machine_details @virtual_machine_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 866 867 868 869 870 871 872 873 874 875 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 839 def update!(**args) @attributes = args[:attributes] if args.key?(:attributes) @aws_api_gateway_rest_api_details = args[:aws_api_gateway_rest_api_details] if args.key?(:aws_api_gateway_rest_api_details) @aws_app_sync_graphql_api_details = args[:aws_app_sync_graphql_api_details] if args.key?(:aws_app_sync_graphql_api_details) @aws_application_load_balancer_details = args[:aws_application_load_balancer_details] if args.key?(:aws_application_load_balancer_details) @aws_autoscaling_group_details = args[:aws_autoscaling_group_details] if args.key?(:aws_autoscaling_group_details) @aws_batch_compute_environment_details = args[:aws_batch_compute_environment_details] if args.key?(:aws_batch_compute_environment_details) @aws_cloud_front_distribution_details = args[:aws_cloud_front_distribution_details] if args.key?(:aws_cloud_front_distribution_details) @aws_dynamodb_table_details = args[:aws_dynamodb_table_details] if args.key?(:aws_dynamodb_table_details) @aws_ebs_volume_details = args[:aws_ebs_volume_details] if args.key?(:aws_ebs_volume_details) @aws_ecr_repository_details = args[:aws_ecr_repository_details] if args.key?(:aws_ecr_repository_details) @aws_ecs_cluster_details = args[:aws_ecs_cluster_details] if args.key?(:aws_ecs_cluster_details) @aws_efs_file_system_details = args[:aws_efs_file_system_details] if args.key?(:aws_efs_file_system_details) @aws_eks_cluster_details = args[:aws_eks_cluster_details] if args.key?(:aws_eks_cluster_details) @aws_elastic_ip_address_details = args[:aws_elastic_ip_address_details] if args.key?(:aws_elastic_ip_address_details) @aws_elastic_network_interface_details = args[:aws_elastic_network_interface_details] if args.key?(:aws_elastic_network_interface_details) @aws_elb_load_balancer_details = args[:aws_elb_load_balancer_details] if args.key?(:aws_elb_load_balancer_details) @aws_internet_gateway_details = args[:aws_internet_gateway_details] if args.key?(:aws_internet_gateway_details) @aws_lambda_function_details = args[:aws_lambda_function_details] if args.key?(:aws_lambda_function_details) @aws_nat_gateway_details = args[:aws_nat_gateway_details] if args.key?(:aws_nat_gateway_details) @aws_redshift_details = args[:aws_redshift_details] if args.key?(:aws_redshift_details) @aws_route53_hosted_zone_details = args[:aws_route53_hosted_zone_details] if args.key?(:aws_route53_hosted_zone_details) @aws_s3_bucket_details = args[:aws_s3_bucket_details] if args.key?(:aws_s3_bucket_details) @aws_sns_topic_details = args[:aws_sns_topic_details] if args.key?(:aws_sns_topic_details) @aws_vpc_details = args[:aws_vpc_details] if args.key?(:aws_vpc_details) @collection_type = args[:collection_type] if args.key?(:collection_type) @database_deployment_details = args[:database_deployment_details] if args.key?(:database_deployment_details) @database_details = args[:database_details] if args.key?(:database_details) @hosting_provider_details = args[:hosting_provider_details] if args.key?(:hosting_provider_details) @labels = args[:labels] if args.key?(:labels) @machine_details = args[:machine_details] if args.key?(:machine_details) @performance_samples = args[:performance_samples] if args.key?(:performance_samples) @report_time = args[:report_time] if args.key?(:report_time) @structured_attributes = args[:structured_attributes] if args.key?(:structured_attributes) @trace_token = args[:trace_token] if args.key?(:trace_token) @virtual_machine_details = args[:virtual_machine_details] if args.key?(:virtual_machine_details) end |