Class: Google::Apis::MigrationcenterV1alpha1::AssetsExportJobPerformanceData
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::AssetsExportJobPerformanceData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Configuration for performance data exports.
Instance Attribute Summary collapse
-
#max_days ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssetsExportJobPerformanceData
constructor
A new instance of AssetsExportJobPerformanceData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssetsExportJobPerformanceData
Returns a new instance of AssetsExportJobPerformanceData.
1209 1210 1211 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1209 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_days ⇒ Fixnum
Optional. When this value is set to a positive integer, performance data will
be returned for the most recent days for which data is available. When this
value is unset (or set to zero), all available data is returned. The maximum
value is 420; values above 420 will be coerced to 420. If unset (0 value) a
default value of 40 will be used.
Corresponds to the JSON property maxDays
1207 1208 1209 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1207 def max_days @max_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1214 1215 1216 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1214 def update!(**args) @max_days = args[:max_days] if args.key?(:max_days) end |