Class: Google::Apis::MigrationcenterV1alpha1::AssetsExportJobPerformanceData
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::AssetsExportJobPerformanceData
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Configuration for performance data exports.
Instance Attribute Summary collapse
-
#max_days ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AssetsExportJobPerformanceData
constructor
A new instance of AssetsExportJobPerformanceData.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AssetsExportJobPerformanceData
Returns a new instance of AssetsExportJobPerformanceData.
1149 1150 1151 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1149 def initialize(**args) update!(**args) end |
Instance Attribute Details
#max_days ⇒ Fixnum
Optional. When this value is set to a positive integer, performance data will
be returned for the most recent days for which data is available. When this
value is unset (or set to zero), all available data is returned. The maximum
value is 420; values above 420 will be coerced to 420. If unset (0 value) a
default value of 40 will be used.
Corresponds to the JSON property maxDays
1147 1148 1149 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1147 def max_days @max_days end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1154 1155 1156 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1154 def update!(**args) @max_days = args[:max_days] if args.key?(:max_days) end |