Class: Google::Apis::MigrationcenterV1alpha1::AzureVmPlatformDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::AzureVmPlatformDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Azure VM specific details.
Instance Attribute Summary collapse
-
#hyperthreading ⇒ String
Whether the machine is hyperthreaded.
-
#location ⇒ String
The location of the machine in the Azure format.
-
#machine_type_label ⇒ String
Azure platform's machine type label.
-
#provisioning_state ⇒ String
Azure platform's provisioning state.
Instance Method Summary collapse
-
#initialize(**args) ⇒ AzureVmPlatformDetails
constructor
A new instance of AzureVmPlatformDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ AzureVmPlatformDetails
Returns a new instance of AzureVmPlatformDetails.
1752 1753 1754 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1752 def initialize(**args) update!(**args) end |
Instance Attribute Details
#hyperthreading ⇒ String
Whether the machine is hyperthreaded.
Corresponds to the JSON property hyperthreading
1735 1736 1737 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1735 def hyperthreading @hyperthreading end |
#location ⇒ String
The location of the machine in the Azure format.
Corresponds to the JSON property location
1740 1741 1742 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1740 def location @location end |
#machine_type_label ⇒ String
Azure platform's machine type label.
Corresponds to the JSON property machineTypeLabel
1745 1746 1747 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1745 def machine_type_label @machine_type_label end |
#provisioning_state ⇒ String
Azure platform's provisioning state.
Corresponds to the JSON property provisioningState
1750 1751 1752 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1750 def provisioning_state @provisioning_state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1757 1758 1759 1760 1761 1762 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 1757 def update!(**args) @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading) @location = args[:location] if args.key?(:location) @machine_type_label = args[:machine_type_label] if args.key?(:machine_type_label) @provisioning_state = args[:provisioning_state] if args.key?(:provisioning_state) end |