Class: Google::Apis::MigrationcenterV1alpha1::ComputeEnginePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

The user preferences relating to Compute Engine target platform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ComputeEnginePreferences

Returns a new instance of ComputeEnginePreferences.



2230
2231
2232
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2230

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#license_typeString

License type to consider when calculating costs for operating systems. If unspecified, costs are calculated based on the default licensing plan. If os_pricing_preferences is specified, it overrides this field. Corresponds to the JSON property licenseType

Returns:

  • (String)


2205
2206
2207
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2205

def license_type
  @license_type
end

#machine_preferencesGoogle::Apis::MigrationcenterV1alpha1::MachinePreferences

The type of machines to consider when calculating virtual machine migration insights and recommendations for Compute Engine. Not all machine types are available in all zones and regions. Corresponds to the JSON property machinePreferences



2212
2213
2214
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2212

def machine_preferences
  @machine_preferences
end

#multithreadingString

Optional. Preferences for multithreading support on Windows Server. Corresponds to the JSON property multithreading

Returns:

  • (String)


2217
2218
2219
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2217

def multithreading
  @multithreading
end

#os_pricing_preferencesGoogle::Apis::MigrationcenterV1alpha1::OperatingSystemPricingPreferences

Pricing options for OS images. Corresponds to the JSON property osPricingPreferences



2222
2223
2224
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2222

def os_pricing_preferences
  @os_pricing_preferences
end

#persistent_disk_typeString

Persistent disk type to use. If unspecified (default), all types are considered, based on available usage data. Corresponds to the JSON property persistentDiskType

Returns:

  • (String)


2228
2229
2230
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2228

def persistent_disk_type
  @persistent_disk_type
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2235
2236
2237
2238
2239
2240
2241
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2235

def update!(**args)
  @license_type = args[:license_type] if args.key?(:license_type)
  @machine_preferences = args[:machine_preferences] if args.key?(:machine_preferences)
  @multithreading = args[:multithreading] if args.key?(:multithreading)
  @os_pricing_preferences = args[:os_pricing_preferences] if args.key?(:os_pricing_preferences)
  @persistent_disk_type = args[:persistent_disk_type] if args.key?(:persistent_disk_type)
end