Class: Google::Apis::MigrationcenterV1alpha1::DailyResourceUsageAggregationNetwork

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Statistical aggregation of network usage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DailyResourceUsageAggregationNetwork

Returns a new instance of DailyResourceUsageAggregationNetwork.



2523
2524
2525
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#egress_bpsGoogle::Apis::MigrationcenterV1alpha1::DailyResourceUsageAggregationStats

Statistical aggregation of samples for a single resource usage. Corresponds to the JSON property egressBps



2516
2517
2518
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2516

def egress_bps
  @egress_bps
end

#ingress_bpsGoogle::Apis::MigrationcenterV1alpha1::DailyResourceUsageAggregationStats

Statistical aggregation of samples for a single resource usage. Corresponds to the JSON property ingressBps



2521
2522
2523
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2521

def ingress_bps
  @ingress_bps
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2528
2529
2530
2531
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 2528

def update!(**args)
  @egress_bps = args[:egress_bps] if args.key?(:egress_bps)
  @ingress_bps = args[:ingress_bps] if args.key?(:ingress_bps)
end