Class: Google::Apis::MigrationcenterV1alpha1::DateTime

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Represents civil time (or occasionally physical time). This type can represent a civil time in one of a few possible ways: * When utc_offset is set and time_zone is unset: a civil time on a calendar day with a particular offset from UTC. * When time_zone is set and utc_offset is unset: a civil time on a calendar day in a particular time zone. * When neither time_zone nor utc_offset is set: a civil time on a calendar day in local time. The date is relative to the Proleptic Gregorian Calendar. If year, month, or day are 0, the DateTime is considered not to have a specific year, month, or day respectively. This type may also be used to represent a physical time if all the date and time fields are set and either case of the time_offset oneof is set. Consider using Timestamp message for physical time instead. If your use case also would like to store the user's timezone, that can be done in another field. This type is more flexible than some applications may want. Make sure to document and validate your application's limitations.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DateTime

Returns a new instance of DateTime.



3218
3219
3220
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3218

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#dayFixnum

Optional. Day of month. Must be from 1 to 31 and valid for the year and month, or 0 if specifying a datetime without a day. Corresponds to the JSON property day

Returns:

  • (Fixnum)


3168
3169
3170
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3168

def day
  @day
end

#hoursFixnum

Optional. Hours of day in 24 hour format. Should be from 0 to 23, defaults to 0 (midnight). An API may choose to allow the value "24:00:00" for scenarios like business closing time. Corresponds to the JSON property hours

Returns:

  • (Fixnum)


3175
3176
3177
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3175

def hours
  @hours
end

#minutesFixnum

Optional. Minutes of hour of day. Must be from 0 to 59, defaults to 0. Corresponds to the JSON property minutes

Returns:

  • (Fixnum)


3180
3181
3182
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3180

def minutes
  @minutes
end

#monthFixnum

Optional. Month of year. Must be from 1 to 12, or 0 if specifying a datetime without a month. Corresponds to the JSON property month

Returns:

  • (Fixnum)


3186
3187
3188
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3186

def month
  @month
end

#nanosFixnum

Optional. Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999, defaults to 0. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


3192
3193
3194
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3192

def nanos
  @nanos
end

#secondsFixnum

Optional. Seconds of minutes of the time. Must normally be from 0 to 59, defaults to 0. An API may allow the value 60 if it allows leap-seconds. Corresponds to the JSON property seconds

Returns:

  • (Fixnum)


3198
3199
3200
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3198

def seconds
  @seconds
end

#time_zoneGoogle::Apis::MigrationcenterV1alpha1::TimeZone

Represents a time zone from the IANA Time Zone Database. Corresponds to the JSON property timeZone



3204
3205
3206
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3204

def time_zone
  @time_zone
end

#utc_offsetString

UTC offset. Must be whole seconds, between -18 hours and +18 hours. For example, a UTC offset of -4:00 would be represented as seconds: -14400. Corresponds to the JSON property utcOffset

Returns:

  • (String)


3210
3211
3212
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3210

def utc_offset
  @utc_offset
end

#yearFixnum

Optional. Year of date. Must be from 1 to 9999, or 0 if specifying a datetime without a year. Corresponds to the JSON property year

Returns:

  • (Fixnum)


3216
3217
3218
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3216

def year
  @year
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3223
3224
3225
3226
3227
3228
3229
3230
3231
3232
3233
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3223

def update!(**args)
  @day = args[:day] if args.key?(:day)
  @hours = args[:hours] if args.key?(:hours)
  @minutes = args[:minutes] if args.key?(:minutes)
  @month = args[:month] if args.key?(:month)
  @nanos = args[:nanos] if args.key?(:nanos)
  @seconds = args[:seconds] if args.key?(:seconds)
  @time_zone = args[:time_zone] if args.key?(:time_zone)
  @utc_offset = args[:utc_offset] if args.key?(:utc_offset)
  @year = args[:year] if args.key?(:year)
end