Class: Google::Apis::MigrationcenterV1alpha1::DiscoveryClient
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::DiscoveryClient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Represents an installed Migration Center Discovery Client instance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#errors ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Status>
Output only.
-
#expire_time ⇒ String
Optional.
-
#heartbeat_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#recommended_versions ⇒ Array<Google::Apis::MigrationcenterV1alpha1::DiscoveryClientDiscoveryClientRecommendedVersion>
Output only.
-
#service_account ⇒ String
Required.
-
#signals_endpoint ⇒ String
Output only.
-
#source ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoveryClient
constructor
A new instance of DiscoveryClient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoveryClient
Returns a new instance of DiscoveryClient.
3377 3378 3379 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3377 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the discovery client was first created.
Corresponds to the JSON property createTime
3294 3295 3296 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3294 def create_time @create_time end |
#description ⇒ String
Optional. Free text description. Maximum length is 1000 characters.
Corresponds to the JSON property description
3299 3300 3301 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3299 def description @description end |
#display_name ⇒ String
Optional. Free text display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
3304 3305 3306 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3304 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Status>
Output only. Errors affecting client functionality.
Corresponds to the JSON property errors
3309 3310 3311 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3309 def errors @errors end |
#expire_time ⇒ String
Optional. Client expiration time in UTC. If specified, the backend will not
accept new frames after this time.
Corresponds to the JSON property expireTime
3315 3316 3317 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3315 def expire_time @expire_time end |
#heartbeat_time ⇒ String
Output only. Last heartbeat time. Healthy clients are expected to send
heartbeats regularly (normally every few minutes).
Corresponds to the JSON property heartbeatTime
3321 3322 3323 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3321 def heartbeat_time @heartbeat_time end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
3326 3327 3328 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3326 def labels @labels end |
#name ⇒ String
Output only. Identifier. Full name of this discovery client.
Corresponds to the JSON property name
3331 3332 3333 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3331 def name @name end |
#recommended_versions ⇒ Array<Google::Apis::MigrationcenterV1alpha1::DiscoveryClientDiscoveryClientRecommendedVersion>
Output only. The recommended versions of the discovery client.
Corresponds to the JSON property recommendedVersions
3336 3337 3338 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3336 def recommended_versions @recommended_versions end |
#service_account ⇒ String
Required. Service account used by the discovery client for various operation.
Corresponds to the JSON property serviceAccount
3341 3342 3343 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3341 def service_account @service_account end |
#signals_endpoint ⇒ String
Output only. This field is intended for internal use.
Corresponds to the JSON property signalsEndpoint
3346 3347 3348 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3346 def signals_endpoint @signals_endpoint end |
#source ⇒ String
Required. Full name of the source object associated with this discovery client.
Corresponds to the JSON property source
3351 3352 3353 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3351 def source @source end |
#state ⇒ String
Output only. Current state of the discovery client.
Corresponds to the JSON property state
3356 3357 3358 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3356 def state @state end |
#ttl ⇒ String
Optional. Input only. Client time-to-live. If specified, the backend will not
accept new frames after this time. This field is input only. The derived
expiration time is provided as output through the expire_time field.
Corresponds to the JSON property ttl
3363 3364 3365 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3363 def ttl @ttl end |
#update_time ⇒ String
Output only. Time when the discovery client was last updated. This value is
not updated by heartbeats, to view the last heartbeat time please refer to the
heartbeat_time field.
Corresponds to the JSON property updateTime
3370 3371 3372 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3370 def update_time @update_time end |
#version ⇒ String
Output only. Client version, as reported in recent heartbeat.
Corresponds to the JSON property version
3375 3376 3377 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3375 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3382 3383 3384 3385 3386 3387 3388 3389 3390 3391 3392 3393 3394 3395 3396 3397 3398 3399 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3382 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @expire_time = args[:expire_time] if args.key?(:expire_time) @heartbeat_time = args[:heartbeat_time] if args.key?(:heartbeat_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @recommended_versions = args[:recommended_versions] if args.key?(:recommended_versions) @service_account = args[:service_account] if args.key?(:service_account) @signals_endpoint = args[:signals_endpoint] if args.key?(:signals_endpoint) @source = args[:source] if args.key?(:source) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |