Class: Google::Apis::MigrationcenterV1alpha1::DiscoveryClient

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Represents an installed Migration Center Discovery Client instance.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoveryClient

Returns a new instance of DiscoveryClient.



3352
3353
3354
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3352

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Time when the discovery client was first created. Corresponds to the JSON property createTime

Returns:

  • (String)


3269
3270
3271
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3269

def create_time
  @create_time
end

#descriptionString

Optional. Free text description. Maximum length is 1000 characters. Corresponds to the JSON property description

Returns:

  • (String)


3274
3275
3276
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3274

def description
  @description
end

#display_nameString

Optional. Free text display name. Maximum length is 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


3279
3280
3281
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3279

def display_name
  @display_name
end

#errorsArray<Google::Apis::MigrationcenterV1alpha1::Status>

Output only. Errors affecting client functionality. Corresponds to the JSON property errors



3284
3285
3286
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3284

def errors
  @errors
end

#expire_timeString

Optional. Client expiration time in UTC. If specified, the backend will not accept new frames after this time. Corresponds to the JSON property expireTime

Returns:

  • (String)


3290
3291
3292
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3290

def expire_time
  @expire_time
end

#heartbeat_timeString

Output only. Last heartbeat time. Healthy clients are expected to send heartbeats regularly (normally every few minutes). Corresponds to the JSON property heartbeatTime

Returns:

  • (String)


3296
3297
3298
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3296

def heartbeat_time
  @heartbeat_time
end

#labelsHash<String,String>

Optional. Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3301
3302
3303
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3301

def labels
  @labels
end

#nameString

Output only. Identifier. Full name of this discovery client. Corresponds to the JSON property name

Returns:

  • (String)


3306
3307
3308
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3306

def name
  @name
end

Output only. The recommended versions of the discovery client. Corresponds to the JSON property recommendedVersions



3311
3312
3313
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3311

def recommended_versions
  @recommended_versions
end

#service_accountString

Required. Service account used by the discovery client for various operation. Corresponds to the JSON property serviceAccount

Returns:

  • (String)


3316
3317
3318
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3316

def 
  @service_account
end

#signals_endpointString

Output only. This field is intended for internal use. Corresponds to the JSON property signalsEndpoint

Returns:

  • (String)


3321
3322
3323
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3321

def signals_endpoint
  @signals_endpoint
end

#sourceString

Required. Full name of the source object associated with this discovery client. Corresponds to the JSON property source

Returns:

  • (String)


3326
3327
3328
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3326

def source
  @source
end

#stateString

Output only. Current state of the discovery client. Corresponds to the JSON property state

Returns:

  • (String)


3331
3332
3333
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3331

def state
  @state
end

#ttlString

Optional. Input only. Client time-to-live. If specified, the backend will not accept new frames after this time. This field is input only. The derived expiration time is provided as output through the expire_time field. Corresponds to the JSON property ttl

Returns:

  • (String)


3338
3339
3340
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3338

def ttl
  @ttl
end

#update_timeString

Output only. Time when the discovery client was last updated. This value is not updated by heartbeats, to view the last heartbeat time please refer to the heartbeat_time field. Corresponds to the JSON property updateTime

Returns:

  • (String)


3345
3346
3347
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3345

def update_time
  @update_time
end

#versionString

Output only. Client version, as reported in recent heartbeat. Corresponds to the JSON property version

Returns:

  • (String)


3350
3351
3352
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3350

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3357
3358
3359
3360
3361
3362
3363
3364
3365
3366
3367
3368
3369
3370
3371
3372
3373
3374
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3357

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @errors = args[:errors] if args.key?(:errors)
  @expire_time = args[:expire_time] if args.key?(:expire_time)
  @heartbeat_time = args[:heartbeat_time] if args.key?(:heartbeat_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @recommended_versions = args[:recommended_versions] if args.key?(:recommended_versions)
  @service_account = args[:service_account] if args.key?(:service_account)
  @signals_endpoint = args[:signals_endpoint] if args.key?(:signals_endpoint)
  @source = args[:source] if args.key?(:source)
  @state = args[:state] if args.key?(:state)
  @ttl = args[:ttl] if args.key?(:ttl)
  @update_time = args[:update_time] if args.key?(:update_time)
  @version = args[:version] if args.key?(:version)
end