Class: Google::Apis::MigrationcenterV1alpha1::DiscoveryClient
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::DiscoveryClient
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Represents an installed Migration Center Discovery Client instance.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#errors ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Status>
Output only.
-
#expire_time ⇒ String
Optional.
-
#heartbeat_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Output only.
-
#recommended_versions ⇒ Array<Google::Apis::MigrationcenterV1alpha1::DiscoveryClientDiscoveryClientRecommendedVersion>
Output only.
-
#service_account ⇒ String
Required.
-
#signals_endpoint ⇒ String
Output only.
-
#source ⇒ String
Required.
-
#state ⇒ String
Output only.
-
#ttl ⇒ String
Optional.
-
#update_time ⇒ String
Output only.
-
#version ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiscoveryClient
constructor
A new instance of DiscoveryClient.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiscoveryClient
Returns a new instance of DiscoveryClient.
3227 3228 3229 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3227 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Time when the discovery client was first created.
Corresponds to the JSON property createTime
3144 3145 3146 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3144 def create_time @create_time end |
#description ⇒ String
Optional. Free text description. Maximum length is 1000 characters.
Corresponds to the JSON property description
3149 3150 3151 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3149 def description @description end |
#display_name ⇒ String
Optional. Free text display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
3154 3155 3156 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3154 def display_name @display_name end |
#errors ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Status>
Output only. Errors affecting client functionality.
Corresponds to the JSON property errors
3159 3160 3161 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3159 def errors @errors end |
#expire_time ⇒ String
Optional. Client expiration time in UTC. If specified, the backend will not
accept new frames after this time.
Corresponds to the JSON property expireTime
3165 3166 3167 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3165 def expire_time @expire_time end |
#heartbeat_time ⇒ String
Output only. Last heartbeat time. Healthy clients are expected to send
heartbeats regularly (normally every few minutes).
Corresponds to the JSON property heartbeatTime
3171 3172 3173 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3171 def heartbeat_time @heartbeat_time end |
#labels ⇒ Hash<String,String>
Optional. Labels as key value pairs.
Corresponds to the JSON property labels
3176 3177 3178 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3176 def labels @labels end |
#name ⇒ String
Output only. Identifier. Full name of this discovery client.
Corresponds to the JSON property name
3181 3182 3183 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3181 def name @name end |
#recommended_versions ⇒ Array<Google::Apis::MigrationcenterV1alpha1::DiscoveryClientDiscoveryClientRecommendedVersion>
Output only. The recommended versions of the discovery client.
Corresponds to the JSON property recommendedVersions
3186 3187 3188 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3186 def recommended_versions @recommended_versions end |
#service_account ⇒ String
Required. Service account used by the discovery client for various operation.
Corresponds to the JSON property serviceAccount
3191 3192 3193 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3191 def service_account @service_account end |
#signals_endpoint ⇒ String
Output only. This field is intended for internal use.
Corresponds to the JSON property signalsEndpoint
3196 3197 3198 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3196 def signals_endpoint @signals_endpoint end |
#source ⇒ String
Required. Full name of the source object associated with this discovery client.
Corresponds to the JSON property source
3201 3202 3203 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3201 def source @source end |
#state ⇒ String
Output only. Current state of the discovery client.
Corresponds to the JSON property state
3206 3207 3208 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3206 def state @state end |
#ttl ⇒ String
Optional. Input only. Client time-to-live. If specified, the backend will not
accept new frames after this time. This field is input only. The derived
expiration time is provided as output through the expire_time field.
Corresponds to the JSON property ttl
3213 3214 3215 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3213 def ttl @ttl end |
#update_time ⇒ String
Output only. Time when the discovery client was last updated. This value is
not updated by heartbeats, to view the last heartbeat time please refer to the
heartbeat_time field.
Corresponds to the JSON property updateTime
3220 3221 3222 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3220 def update_time @update_time end |
#version ⇒ String
Output only. Client version, as reported in recent heartbeat.
Corresponds to the JSON property version
3225 3226 3227 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3225 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3232 3233 3234 3235 3236 3237 3238 3239 3240 3241 3242 3243 3244 3245 3246 3247 3248 3249 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3232 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @errors = args[:errors] if args.key?(:errors) @expire_time = args[:expire_time] if args.key?(:expire_time) @heartbeat_time = args[:heartbeat_time] if args.key?(:heartbeat_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @recommended_versions = args[:recommended_versions] if args.key?(:recommended_versions) @service_account = args[:service_account] if args.key?(:service_account) @signals_endpoint = args[:signals_endpoint] if args.key?(:signals_endpoint) @source = args[:source] if args.key?(:source) @state = args[:state] if args.key?(:state) @ttl = args[:ttl] if args.key?(:ttl) @update_time = args[:update_time] if args.key?(:update_time) @version = args[:version] if args.key?(:version) end |