Class: Google::Apis::MigrationcenterV1alpha1::ErrorFrame
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ErrorFrame
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Message representing a frame which failed to be processed due to an error.
Instance Attribute Summary collapse
-
#ingestion_time ⇒ String
Output only.
-
#name ⇒ String
Output only.
-
#original_frame ⇒ Google::Apis::MigrationcenterV1alpha1::AssetFrame
Contains data reported from an inventory source on an asset.
-
#violations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::FrameViolationEntry>
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ErrorFrame
constructor
A new instance of ErrorFrame.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ErrorFrame
Returns a new instance of ErrorFrame.
3549 3550 3551 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3549 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ingestion_time ⇒ String
Output only. Frame ingestion time.
Corresponds to the JSON property ingestionTime
3532 3533 3534 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3532 def ingestion_time @ingestion_time end |
#name ⇒ String
Output only. The identifier of the ErrorFrame.
Corresponds to the JSON property name
3537 3538 3539 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3537 def name @name end |
#original_frame ⇒ Google::Apis::MigrationcenterV1alpha1::AssetFrame
Contains data reported from an inventory source on an asset.
Corresponds to the JSON property originalFrame
3542 3543 3544 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3542 def original_frame @original_frame end |
#violations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::FrameViolationEntry>
Output only. All the violations that were detected for the frame.
Corresponds to the JSON property violations
3547 3548 3549 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3547 def violations @violations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3554 3555 3556 3557 3558 3559 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3554 def update!(**args) @ingestion_time = args[:ingestion_time] if args.key?(:ingestion_time) @name = args[:name] if args.key?(:name) @original_frame = args[:original_frame] if args.key?(:original_frame) @violations = args[:violations] if args.key?(:violations) end |