Class: Google::Apis::MigrationcenterV1alpha1::FileValidationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that aggregates the validation errors found in an import job file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileValidationReport

Returns a new instance of FileValidationReport.



3782
3783
3784
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3782

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_errorsArray<Google::Apis::MigrationcenterV1alpha1::ImportError>

List of file level errors. Corresponds to the JSON property fileErrors



3764
3765
3766
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3764

def file_errors
  @file_errors
end

#file_nameString

The name of the file. Corresponds to the JSON property fileName

Returns:

  • (String)


3769
3770
3771
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3769

def file_name
  @file_name
end

#partial_reportBoolean Also known as: partial_report?

Flag indicating that processing was aborted due to maximum number of errors. Corresponds to the JSON property partialReport

Returns:

  • (Boolean)


3774
3775
3776
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3774

def partial_report
  @partial_report
end

#row_errorsArray<Google::Apis::MigrationcenterV1alpha1::ImportRowError>

Partial list of rows that encountered validation error. Corresponds to the JSON property rowErrors



3780
3781
3782
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3780

def row_errors
  @row_errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3787
3788
3789
3790
3791
3792
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3787

def update!(**args)
  @file_errors = args[:file_errors] if args.key?(:file_errors)
  @file_name = args[:file_name] if args.key?(:file_name)
  @partial_report = args[:partial_report] if args.key?(:partial_report)
  @row_errors = args[:row_errors] if args.key?(:row_errors)
end