Class: Google::Apis::MigrationcenterV1alpha1::FileValidationReport

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that aggregates the validation errors found in an import job file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FileValidationReport

Returns a new instance of FileValidationReport.



3657
3658
3659
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3657

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#file_errorsArray<Google::Apis::MigrationcenterV1alpha1::ImportError>

List of file level errors. Corresponds to the JSON property fileErrors



3639
3640
3641
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3639

def file_errors
  @file_errors
end

#file_nameString

The name of the file. Corresponds to the JSON property fileName

Returns:

  • (String)


3644
3645
3646
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3644

def file_name
  @file_name
end

#partial_reportBoolean Also known as: partial_report?

Flag indicating that processing was aborted due to maximum number of errors. Corresponds to the JSON property partialReport

Returns:

  • (Boolean)


3649
3650
3651
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3649

def partial_report
  @partial_report
end

#row_errorsArray<Google::Apis::MigrationcenterV1alpha1::ImportRowError>

Partial list of rows that encountered validation error. Corresponds to the JSON property rowErrors



3655
3656
3657
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3655

def row_errors
  @row_errors
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3662
3663
3664
3665
3666
3667
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3662

def update!(**args)
  @file_errors = args[:file_errors] if args.key?(:file_errors)
  @file_name = args[:file_name] if args.key?(:file_name)
  @partial_report = args[:partial_report] if args.key?(:partial_report)
  @row_errors = args[:row_errors] if args.key?(:row_errors)
end