Class: Google::Apis::MigrationcenterV1alpha1::FstabEntry
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::FstabEntry
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Single fstab entry.
Instance Attribute Summary collapse
-
#file ⇒ String
The mount point for the filesystem.
-
#freq ⇒ Fixnum
Used by dump to determine which filesystems need to be dumped.
-
#mntops ⇒ String
Mount options associated with the filesystem.
-
#passno ⇒ Fixnum
Used by the fsck(8) program to determine the order in which filesystem checks are done at reboot time.
-
#spec ⇒ String
The block special device or remote filesystem to be mounted.
-
#vfstype ⇒ String
The type of the filesystem.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FstabEntry
constructor
A new instance of FstabEntry.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FstabEntry
Returns a new instance of FstabEntry.
3769 3770 3771 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3769 def initialize(**args) update!(**args) end |
Instance Attribute Details
#file ⇒ String
The mount point for the filesystem.
Corresponds to the JSON property file
3741 3742 3743 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3741 def file @file end |
#freq ⇒ Fixnum
Used by dump to determine which filesystems need to be dumped.
Corresponds to the JSON property freq
3746 3747 3748 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3746 def freq @freq end |
#mntops ⇒ String
Mount options associated with the filesystem.
Corresponds to the JSON property mntops
3751 3752 3753 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3751 def mntops @mntops end |
#passno ⇒ Fixnum
Used by the fsck(8) program to determine the order in which filesystem checks
are done at reboot time.
Corresponds to the JSON property passno
3757 3758 3759 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3757 def passno @passno end |
#spec ⇒ String
The block special device or remote filesystem to be mounted.
Corresponds to the JSON property spec
3762 3763 3764 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3762 def spec @spec end |
#vfstype ⇒ String
The type of the filesystem.
Corresponds to the JSON property vfstype
3767 3768 3769 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3767 def vfstype @vfstype end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3774 3775 3776 3777 3778 3779 3780 3781 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3774 def update!(**args) @file = args[:file] if args.key?(:file) @freq = args[:freq] if args.key?(:freq) @mntops = args[:mntops] if args.key?(:mntops) @passno = args[:passno] if args.key?(:passno) @spec = args[:spec] if args.key?(:spec) @vfstype = args[:vfstype] if args.key?(:vfstype) end |