Class: Google::Apis::MigrationcenterV1alpha1::GenericInsight
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::GenericInsight
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A generic insight about an asset.
Instance Attribute Summary collapse
-
#additional_information ⇒ Array<String>
Output only.
-
#default_message ⇒ String
Output only.
-
#message_id ⇒ Fixnum
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GenericInsight
constructor
A new instance of GenericInsight.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GenericInsight
Returns a new instance of GenericInsight.
3978 3979 3980 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3978 def initialize(**args) update!(**args) end |
Instance Attribute Details
#additional_information ⇒ Array<String>
Output only. Additional information about the insight, each entry can be a
logical entry and must make sense if it is displayed with line breaks between
each entry. Text can contain md style links.
Corresponds to the JSON property additionalInformation
3962 3963 3964 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3962 def additional_information @additional_information end |
#default_message ⇒ String
Output only. In case message_code is not yet known by the client
default_message will be the message to be used instead. Text can contain md
file style links.
Corresponds to the JSON property defaultMessage
3969 3970 3971 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3969 def @default_message end |
#message_id ⇒ Fixnum
Output only. Represents a globally unique message id for this insight, can be
used for localization purposes, in case message_code is not yet known by the
client use default_message instead.
Corresponds to the JSON property messageId
3976 3977 3978 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3976 def @message_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3983 3984 3985 3986 3987 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3983 def update!(**args) @additional_information = args[:additional_information] if args.key?(:additional_information) @default_message = args[:default_message] if args.key?(:default_message) @message_id = args[:message_id] if args.key?(:message_id) end |