Class: Google::Apis::MigrationcenterV1alpha1::GenericPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Generic platform details.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenericPlatformDetails

Returns a new instance of GenericPlatformDetails.



4006
4007
4008
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4006

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


3997
3998
3999
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3997

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different VMs in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


4004
4005
4006
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4004

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4011
4012
4013
4014
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4011

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end