Class: Google::Apis::MigrationcenterV1alpha1::Group
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::Group
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A resource that represents an asset group. The purpose of an asset group is to bundle a set of assets that have something in common, while allowing users to add annotations to the group. An asset can belong to multiple groups.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Labels as key value pairs.
-
#name ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Group
constructor
A new instance of Group.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Group
Returns a new instance of Group.
4066 4067 4068 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4066 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. The timestamp when the group was created.
Corresponds to the JSON property createTime
4039 4040 4041 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4039 def create_time @create_time end |
#description ⇒ String
Optional. The description of the group.
Corresponds to the JSON property description
4044 4045 4046 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4044 def description @description end |
#display_name ⇒ String
Optional. User-friendly display name.
Corresponds to the JSON property displayName
4049 4050 4051 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4049 def display_name @display_name end |
#labels ⇒ Hash<String,String>
Labels as key value pairs.
Corresponds to the JSON property labels
4054 4055 4056 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4054 def labels @labels end |
#name ⇒ String
Output only. The name of the group.
Corresponds to the JSON property name
4059 4060 4061 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4059 def name @name end |
#update_time ⇒ String
Output only. The timestamp when the group was last updated.
Corresponds to the JSON property updateTime
4064 4065 4066 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4064 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4071 4072 4073 4074 4075 4076 4077 4078 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4071 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @update_time = args[:update_time] if args.key?(:update_time) end |