Class: Google::Apis::MigrationcenterV1alpha1::Group

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that represents an asset group. The purpose of an asset group is to bundle a set of assets that have something in common, while allowing users to add annotations to the group. An asset can belong to multiple groups.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Group

Returns a new instance of Group.



3941
3942
3943
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3941

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the group was created. Corresponds to the JSON property createTime

Returns:

  • (String)


3914
3915
3916
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3914

def create_time
  @create_time
end

#descriptionString

Optional. The description of the group. Corresponds to the JSON property description

Returns:

  • (String)


3919
3920
3921
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3919

def description
  @description
end

#display_nameString

Optional. User-friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


3924
3925
3926
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3924

def display_name
  @display_name
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


3929
3930
3931
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3929

def labels
  @labels
end

#nameString

Output only. The name of the group. Corresponds to the JSON property name

Returns:

  • (String)


3934
3935
3936
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3934

def name
  @name
end

#update_timeString

Output only. The timestamp when the group was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


3939
3940
3941
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3939

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3946
3947
3948
3949
3950
3951
3952
3953
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 3946

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @update_time = args[:update_time] if args.key?(:update_time)
end