Class: Google::Apis::MigrationcenterV1alpha1::HostingProviderDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::HostingProviderDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Details about the hosting platform of the asset.
Instance Attribute Summary collapse
-
#aws ⇒ Google::Apis::MigrationcenterV1alpha1::HostingProviderDetailsAws
Details for AWS platform.
-
#create_time ⇒ String
Optional.
-
#display_name ⇒ String
Optional.
-
#location ⇒ Google::Apis::MigrationcenterV1alpha1::ResourceLocation
Location of a resource.
-
#original_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ HostingProviderDetails
constructor
A new instance of HostingProviderDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ HostingProviderDetails
Returns a new instance of HostingProviderDetails.
4356 4357 4358 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4356 def initialize(**args) update!(**args) end |
Instance Attribute Details
#aws ⇒ Google::Apis::MigrationcenterV1alpha1::HostingProviderDetailsAws
Details for AWS platform.
Corresponds to the JSON property aws
4334 4335 4336 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4334 def aws @aws end |
#create_time ⇒ String
Optional. The timestamp when resource was created in the hosting provider.
Corresponds to the JSON property createTime
4339 4340 4341 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4339 def create_time @create_time end |
#display_name ⇒ String
Optional. Display name of the asset.
Corresponds to the JSON property displayName
4344 4345 4346 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4344 def display_name @display_name end |
#location ⇒ Google::Apis::MigrationcenterV1alpha1::ResourceLocation
Location of a resource.
Corresponds to the JSON property location
4349 4350 4351 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4349 def location @location end |
#original_id ⇒ String
Optional. Unique identifier for the asset in the hosting provider.
Corresponds to the JSON property originalId
4354 4355 4356 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4354 def original_id @original_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4361 4362 4363 4364 4365 4366 4367 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4361 def update!(**args) @aws = args[:aws] if args.key?(:aws) @create_time = args[:create_time] if args.key?(:create_time) @display_name = args[:display_name] if args.key?(:display_name) @location = args[:location] if args.key?(:location) @original_id = args[:original_id] if args.key?(:original_id) end |