Class: Google::Apis::MigrationcenterV1alpha1::ImportDataFile

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that represents a payload file in an import job.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportDataFile

Returns a new instance of ImportDataFile.



4467
4468
4469
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4467

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the file was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4440
4441
4442
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4440

def create_time
  @create_time
end

#display_nameString

Optional. User-friendly display name. Maximum length is 256 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


4445
4446
4447
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4445

def display_name
  @display_name
end

#formatString

Required. The payload format. Corresponds to the JSON property format

Returns:

  • (String)


4450
4451
4452
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4450

def format
  @format
end

#nameString

Output only. The name of the file. Corresponds to the JSON property name

Returns:

  • (String)


4455
4456
4457
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4455

def name
  @name
end

#stateString

Output only. The state of the import data file. Corresponds to the JSON property state

Returns:

  • (String)


4460
4461
4462
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4460

def state
  @state
end

#upload_file_infoGoogle::Apis::MigrationcenterV1alpha1::UploadFileInfo

A resource that contains a URI to which a data file can be uploaded. Corresponds to the JSON property uploadFileInfo



4465
4466
4467
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4465

def upload_file_info
  @upload_file_info
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4472
4473
4474
4475
4476
4477
4478
4479
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4472

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @format = args[:format] if args.key?(:format)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @upload_file_info = args[:upload_file_info] if args.key?(:upload_file_info)
end