Class: Google::Apis::MigrationcenterV1alpha1::ImportJob

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A resource that represents the background job that imports asset frames.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImportJob

Returns a new instance of ImportJob.



4446
4447
4448
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4446

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#asset_sourceString

Required. Reference to a source. Corresponds to the JSON property assetSource

Returns:

  • (String)


4389
4390
4391
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4389

def asset_source
  @asset_source
end

#complete_timeString

Output only. The timestamp when the import job was completed. Corresponds to the JSON property completeTime

Returns:

  • (String)


4394
4395
4396
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4394

def complete_time
  @complete_time
end

#create_timeString

Output only. The timestamp when the import job was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4399
4400
4401
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4399

def create_time
  @create_time
end

#display_nameString

User-friendly display name. Maximum length is 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


4404
4405
4406
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4404

def display_name
  @display_name
end

#execution_reportGoogle::Apis::MigrationcenterV1alpha1::ExecutionReport

A resource that reports result of the import job execution. Corresponds to the JSON property executionReport



4409
4410
4411
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4409

def execution_report
  @execution_report
end

#gcs_payloadGoogle::Apis::MigrationcenterV1alpha1::GcsPayloadInfo

A resource that represents a payload hosted on Google Cloud Storage. Corresponds to the JSON property gcsPayload



4414
4415
4416
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4414

def gcs_payload
  @gcs_payload
end

#inline_payloadGoogle::Apis::MigrationcenterV1alpha1::InlinePayloadInfo

A resource that represents the inline import job payload. Corresponds to the JSON property inlinePayload



4419
4420
4421
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4419

def inline_payload
  @inline_payload
end

#labelsHash<String,String>

Labels as key value pairs. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4424
4425
4426
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4424

def labels
  @labels
end

#nameString

Output only. The full name of the import job. Corresponds to the JSON property name

Returns:

  • (String)


4429
4430
4431
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4429

def name
  @name
end

#stateString

Output only. The state of the import job. Corresponds to the JSON property state

Returns:

  • (String)


4434
4435
4436
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4434

def state
  @state
end

#update_timeString

Output only. The timestamp when the import job was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4439
4440
4441
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4439

def update_time
  @update_time
end

#validation_reportGoogle::Apis::MigrationcenterV1alpha1::ValidationReport

A resource that aggregates errors across import job files. Corresponds to the JSON property validationReport



4444
4445
4446
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4444

def validation_report
  @validation_report
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4451
4452
4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
4463
4464
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 4451

def update!(**args)
  @asset_source = args[:asset_source] if args.key?(:asset_source)
  @complete_time = args[:complete_time] if args.key?(:complete_time)
  @create_time = args[:create_time] if args.key?(:create_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @execution_report = args[:execution_report] if args.key?(:execution_report)
  @gcs_payload = args[:gcs_payload] if args.key?(:gcs_payload)
  @inline_payload = args[:inline_payload] if args.key?(:inline_payload)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @update_time = args[:update_time] if args.key?(:update_time)
  @validation_report = args[:validation_report] if args.key?(:validation_report)
end