Class: Google::Apis::MigrationcenterV1alpha1::ListRelationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ListRelationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Response message for listing relations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#relations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Relation>
A list of relations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRelationsResponse
constructor
A new instance of ListRelationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRelationsResponse
Returns a new instance of ListRelationsResponse.
5192 5193 5194 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5192 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
5185 5186 5187 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5185 def next_page_token @next_page_token end |
#relations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Relation>
A list of relations.
Corresponds to the JSON property relations
5190 5191 5192 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5190 def relations @relations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5197 5198 5199 5200 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5197 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @relations = args[:relations] if args.key?(:relations) end |