Class: Google::Apis::MigrationcenterV1alpha1::ListRelationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ListRelationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Response message for listing relations.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token identifying a page of results the server should return.
-
#relations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Relation>
A list of relations.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListRelationsResponse
constructor
A new instance of ListRelationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListRelationsResponse
Returns a new instance of ListRelationsResponse.
5067 5068 5069 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5067 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token identifying a page of results the server should return.
Corresponds to the JSON property nextPageToken
5060 5061 5062 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5060 def next_page_token @next_page_token end |
#relations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::Relation>
A list of relations.
Corresponds to the JSON property relations
5065 5066 5067 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5065 def relations @relations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5072 5073 5074 5075 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5072 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @relations = args[:relations] if args.key?(:relations) end |