Class: Google::Apis::MigrationcenterV1alpha1::MachineDiskDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::MachineDiskDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Details of machine disks.
Instance Attribute Summary collapse
-
#disks ⇒ Google::Apis::MigrationcenterV1alpha1::DiskEntryList
VM disks.
-
#raw_scan_result ⇒ String
Raw disk scan result.
-
#total_capacity_bytes ⇒ Fixnum
Disk total Capacity.
-
#total_free_bytes ⇒ Fixnum
Total disk free space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineDiskDetails
constructor
A new instance of MachineDiskDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineDiskDetails
Returns a new instance of MachineDiskDetails.
5540 5541 5542 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5540 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Google::Apis::MigrationcenterV1alpha1::DiskEntryList
VM disks.
Corresponds to the JSON property disks
5521 5522 5523 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5521 def disks @disks end |
#raw_scan_result ⇒ String
Raw disk scan result. This field is intended for human inspection. The format
of this field may be lsblk output or any another raw output. The exact format
may change without notice and should not be relied upon.
Corresponds to the JSON property rawScanResult
5528 5529 5530 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5528 def raw_scan_result @raw_scan_result end |
#total_capacity_bytes ⇒ Fixnum
Disk total Capacity.
Corresponds to the JSON property totalCapacityBytes
5533 5534 5535 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5533 def total_capacity_bytes @total_capacity_bytes end |
#total_free_bytes ⇒ Fixnum
Total disk free space.
Corresponds to the JSON property totalFreeBytes
5538 5539 5540 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5538 def total_free_bytes @total_free_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5545 5546 5547 5548 5549 5550 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5545 def update!(**args) @disks = args[:disks] if args.key?(:disks) @raw_scan_result = args[:raw_scan_result] if args.key?(:raw_scan_result) @total_capacity_bytes = args[:total_capacity_bytes] if args.key?(:total_capacity_bytes) @total_free_bytes = args[:total_free_bytes] if args.key?(:total_free_bytes) end |