Class: Google::Apis::MigrationcenterV1alpha1::MachineDiskDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::MachineDiskDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Details of machine disks.
Instance Attribute Summary collapse
-
#disks ⇒ Google::Apis::MigrationcenterV1alpha1::DiskEntryList
VM disks.
-
#raw_scan_result ⇒ String
Raw disk scan result.
-
#total_capacity_bytes ⇒ Fixnum
Disk total Capacity.
-
#total_free_bytes ⇒ Fixnum
Total disk free space.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MachineDiskDetails
constructor
A new instance of MachineDiskDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MachineDiskDetails
Returns a new instance of MachineDiskDetails.
5415 5416 5417 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5415 def initialize(**args) update!(**args) end |
Instance Attribute Details
#disks ⇒ Google::Apis::MigrationcenterV1alpha1::DiskEntryList
VM disks.
Corresponds to the JSON property disks
5396 5397 5398 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5396 def disks @disks end |
#raw_scan_result ⇒ String
Raw disk scan result. This field is intended for human inspection. The format
of this field may be lsblk output or any another raw output. The exact format
may change without notice and should not be relied upon.
Corresponds to the JSON property rawScanResult
5403 5404 5405 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5403 def raw_scan_result @raw_scan_result end |
#total_capacity_bytes ⇒ Fixnum
Disk total Capacity.
Corresponds to the JSON property totalCapacityBytes
5408 5409 5410 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5408 def total_capacity_bytes @total_capacity_bytes end |
#total_free_bytes ⇒ Fixnum
Total disk free space.
Corresponds to the JSON property totalFreeBytes
5413 5414 5415 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5413 def total_free_bytes @total_free_bytes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5420 5421 5422 5423 5424 5425 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5420 def update!(**args) @disks = args[:disks] if args.key?(:disks) @raw_scan_result = args[:raw_scan_result] if args.key?(:raw_scan_result) @total_capacity_bytes = args[:total_capacity_bytes] if args.key?(:total_capacity_bytes) @total_free_bytes = args[:total_free_bytes] if args.key?(:total_free_bytes) end |