Class: Google::Apis::MigrationcenterV1alpha1::MachinePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

The type of machines to consider when calculating virtual machine migration insights and recommendations for Compute Engine. Not all machine types are available in all zones and regions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MachinePreferences

Returns a new instance of MachinePreferences.



5484
5485
5486
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5484

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_machine_seriesArray<Google::Apis::MigrationcenterV1alpha1::MachineSeries>

Compute Engine machine series to consider for insights and recommendations. If empty, no restriction is applied on the machine series. Corresponds to the JSON property allowedMachineSeries



5482
5483
5484
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5482

def allowed_machine_series
  @allowed_machine_series
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5489
5490
5491
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5489

def update!(**args)
  @allowed_machine_series = args[:allowed_machine_series] if args.key?(:allowed_machine_series)
end