Class: Google::Apis::MigrationcenterV1alpha1::Money

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Represents an amount of money with its currency type.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Money

Returns a new instance of Money.



5741
5742
5743
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5741

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#currency_codeString

The three-letter currency code defined in ISO 4217. Corresponds to the JSON property currencyCode

Returns:

  • (String)


5724
5725
5726
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5724

def currency_code
  @currency_code
end

#nanosFixnum

Number of nano (10^-9) units of the amount. The value must be between -999,999, 999 and +999,999,999 inclusive. If units is positive, nanos must be positive or zero. If units is zero, nanos can be positive, zero, or negative. If units is negative, nanos must be negative or zero. For example $-1.75 is represented as units=-1 and nanos=-750,000,000. Corresponds to the JSON property nanos

Returns:

  • (Fixnum)


5733
5734
5735
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5733

def nanos
  @nanos
end

#unitsFixnum

The whole units of the amount. For example if currencyCode is "USD", then 1 unit is one US dollar. Corresponds to the JSON property units

Returns:

  • (Fixnum)


5739
5740
5741
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5739

def units
  @units
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5746
5747
5748
5749
5750
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5746

def update!(**args)
  @currency_code = args[:currency_code] if args.key?(:currency_code)
  @nanos = args[:nanos] if args.key?(:nanos)
  @units = args[:units] if args.key?(:units)
end