Class: Google::Apis::MigrationcenterV1alpha1::Money
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::Money
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Represents an amount of money with its currency type.
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
-
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount.
-
#units ⇒ Fixnum
The whole units of the amount.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Money
constructor
A new instance of Money.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Money
Returns a new instance of Money.
5616 5617 5618 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5616 def initialize(**args) update!(**args) end |
Instance Attribute Details
#currency_code ⇒ String
The three-letter currency code defined in ISO 4217.
Corresponds to the JSON property currencyCode
5599 5600 5601 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5599 def currency_code @currency_code end |
#nanos ⇒ Fixnum
Number of nano (10^-9) units of the amount. The value must be between -999,999,
999 and +999,999,999 inclusive. If units is positive, nanos must be
positive or zero. If units is zero, nanos can be positive, zero, or
negative. If units is negative, nanos must be negative or zero. For
example $-1.75 is represented as units=-1 and nanos=-750,000,000.
Corresponds to the JSON property nanos
5608 5609 5610 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5608 def nanos @nanos end |
#units ⇒ Fixnum
The whole units of the amount. For example if currencyCode is "USD", then
1 unit is one US dollar.
Corresponds to the JSON property units
5614 5615 5616 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5614 def units @units end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5621 5622 5623 5624 5625 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 5621 def update!(**args) @currency_code = args[:currency_code] if args.key?(:currency_code) @nanos = args[:nanos] if args.key?(:nanos) @units = args[:units] if args.key?(:units) end |