Class: Google::Apis::MigrationcenterV1alpha1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



6434
6435
6436
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


6398
6399
6400
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6398

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6403
6404
6405
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6403

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


6408
6409
6410
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6408

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


6416
6417
6418
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6416

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


6422
6423
6424
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6422

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


6427
6428
6429
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6427

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


6432
6433
6434
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6432

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6439
6440
6441
6442
6443
6444
6445
6446
6447
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6439

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end