Class: Google::Apis::MigrationcenterV1alpha1::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



6309
6310
6311
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6309

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


6273
6274
6275
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6273

def api_version
  @api_version
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6278
6279
6280
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6278

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


6283
6284
6285
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6283

def end_time
  @end_time
end

#requested_cancellationBoolean Also known as: requested_cancellation?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have been cancelled successfully have Operation. error value with a google.rpc.Status.code of 1, corresponding to Code. CANCELLED. Corresponds to the JSON property requestedCancellation

Returns:

  • (Boolean)


6291
6292
6293
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6291

def requested_cancellation
  @requested_cancellation
end

#status_messageString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusMessage

Returns:

  • (String)


6297
6298
6299
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6297

def status_message
  @status_message
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


6302
6303
6304
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6302

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


6307
6308
6309
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6307

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6314
6315
6316
6317
6318
6319
6320
6321
6322
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6314

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation)
  @status_message = args[:status_message] if args.key?(:status_message)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end