Class: Google::Apis::MigrationcenterV1alpha1::PhysicalPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Platform specific details for Physical Machines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhysicalPlatformDetails

Returns a new instance of PhysicalPlatformDetails.



6585
6586
6587
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6585

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


6576
6577
6578
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6576

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different machines in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


6583
6584
6585
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6583

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6590
6591
6592
6593
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6590

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end