Class: Google::Apis::MigrationcenterV1alpha1::PhysicalPlatformDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Platform specific details for Physical Machines.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PhysicalPlatformDetails

Returns a new instance of PhysicalPlatformDetails.



6460
6461
6462
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6460

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#hyperthreadingString

Whether the machine is hyperthreaded. Corresponds to the JSON property hyperthreading

Returns:

  • (String)


6451
6452
6453
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6451

def hyperthreading
  @hyperthreading
end

#locationString

Free text representation of the machine location. The format of this field should not be relied on. Different machines in the same location may have different string values for this field. Corresponds to the JSON property location

Returns:

  • (String)


6458
6459
6460
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6458

def location
  @location
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6465
6466
6467
6468
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6465

def update!(**args)
  @hyperthreading = args[:hyperthreading] if args.key?(:hyperthreading)
  @location = args[:location] if args.key?(:location)
end