Class: Google::Apis::MigrationcenterV1alpha1::PreferenceSet

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

The preferences that apply to all assets in a given context.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PreferenceSet

Returns a new instance of PreferenceSet.



6851
6852
6853
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6851

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the preference set was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6810
6811
6812
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6810

def create_time
  @create_time
end

#database_preferencesGoogle::Apis::MigrationcenterV1alpha1::DatabasePreferences

DatabasePreferences enables you to create sets of preferences for your migrated databases. Corresponds to the JSON property databasePreferences



6816
6817
6818
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6816

def database_preferences
  @database_preferences
end

#descriptionString

A description of the preference set. Corresponds to the JSON property description

Returns:

  • (String)


6821
6822
6823
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6821

def description
  @description
end

#display_nameString

User-friendly display name. Maximum length is 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6826
6827
6828
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6826

def display_name
  @display_name
end

#nameString

Output only. Name of the PreferenceSet. Corresponds to the JSON property name

Returns:

  • (String)


6831
6832
6833
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6831

def name
  @name
end

#region_preferencesGoogle::Apis::MigrationcenterV1alpha1::RegionPreferences

The user preferences relating to target regions. Corresponds to the JSON property regionPreferences



6836
6837
6838
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6836

def region_preferences
  @region_preferences
end

#update_timeString

Output only. The timestamp when the preference set was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6841
6842
6843
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6841

def update_time
  @update_time
end

#virtual_machine_preferencesGoogle::Apis::MigrationcenterV1alpha1::VirtualMachinePreferences

VirtualMachinePreferences enables you to create sets of preferences, for example, a geographical location and pricing track, for your migrated virtual machines. The set of preferences influence recommendations for migrating virtual machine assets. Corresponds to the JSON property virtualMachinePreferences



6849
6850
6851
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6849

def virtual_machine_preferences
  @virtual_machine_preferences
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6856
6857
6858
6859
6860
6861
6862
6863
6864
6865
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6856

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @database_preferences = args[:database_preferences] if args.key?(:database_preferences)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @region_preferences = args[:region_preferences] if args.key?(:region_preferences)
  @update_time = args[:update_time] if args.key?(:update_time)
  @virtual_machine_preferences = args[:virtual_machine_preferences] if args.key?(:virtual_machine_preferences)
end