Class: Google::Apis::MigrationcenterV1alpha1::Report
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::Report
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Report represents a point-in-time rendering of the ReportConfig results.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Free-text description.
-
#display_name ⇒ String
User-friendly display name.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Report creation state.
-
#summary ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummary
Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report.
-
#type ⇒ String
Report type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Report
constructor
A new instance of Report.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Report
Returns a new instance of Report.
7021 7022 7023 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7021 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation timestamp.
Corresponds to the JSON property createTime
6983 6984 6985 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6983 def create_time @create_time end |
#description ⇒ String
Free-text description.
Corresponds to the JSON property description
6988 6989 6990 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6988 def description @description end |
#display_name ⇒ String
User-friendly display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
6993 6994 6995 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6993 def display_name @display_name end |
#name ⇒ String
Output only. Name of resource.
Corresponds to the JSON property name
6998 6999 7000 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6998 def name @name end |
#state ⇒ String
Report creation state.
Corresponds to the JSON property state
7003 7004 7005 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7003 def state @state end |
#summary ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummary
Describes the Summary view of a Report, which contains aggregated values for
all the groups and preference sets included in this Report.
Corresponds to the JSON property summary
7009 7010 7011 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7009 def summary @summary end |
#type ⇒ String
Report type.
Corresponds to the JSON property type
7014 7015 7016 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7014 def type @type end |
#update_time ⇒ String
Output only. Last update timestamp.
Corresponds to the JSON property updateTime
7019 7020 7021 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7019 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7026 7027 7028 7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7026 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @summary = args[:summary] if args.key?(:summary) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |