Class: Google::Apis::MigrationcenterV1alpha1::Report

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Report represents a point-in-time rendering of the ReportConfig results.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Report

Returns a new instance of Report.



6896
6897
6898
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. Creation timestamp. Corresponds to the JSON property createTime

Returns:

  • (String)


6858
6859
6860
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6858

def create_time
  @create_time
end

#descriptionString

Free-text description. Corresponds to the JSON property description

Returns:

  • (String)


6863
6864
6865
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6863

def description
  @description
end

#display_nameString

User-friendly display name. Maximum length is 63 characters. Corresponds to the JSON property displayName

Returns:

  • (String)


6868
6869
6870
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6868

def display_name
  @display_name
end

#nameString

Output only. Name of resource. Corresponds to the JSON property name

Returns:

  • (String)


6873
6874
6875
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6873

def name
  @name
end

#stateString

Report creation state. Corresponds to the JSON property state

Returns:

  • (String)


6878
6879
6880
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6878

def state
  @state
end

#summaryGoogle::Apis::MigrationcenterV1alpha1::ReportSummary

Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report. Corresponds to the JSON property summary



6884
6885
6886
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6884

def summary
  @summary
end

#typeString

Report type. Corresponds to the JSON property type

Returns:

  • (String)


6889
6890
6891
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6889

def type
  @type
end

#update_timeString

Output only. Last update timestamp. Corresponds to the JSON property updateTime

Returns:

  • (String)


6894
6895
6896
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6894

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6901
6902
6903
6904
6905
6906
6907
6908
6909
6910
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6901

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @name = args[:name] if args.key?(:name)
  @state = args[:state] if args.key?(:state)
  @summary = args[:summary] if args.key?(:summary)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end