Class: Google::Apis::MigrationcenterV1alpha1::Report
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::Report
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Report represents a point-in-time rendering of the ReportConfig results.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#description ⇒ String
Free-text description.
-
#display_name ⇒ String
User-friendly display name.
-
#name ⇒ String
Output only.
-
#state ⇒ String
Report creation state.
-
#summary ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummary
Describes the Summary view of a Report, which contains aggregated values for all the groups and preference sets included in this Report.
-
#type ⇒ String
Report type.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Report
constructor
A new instance of Report.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Report
Returns a new instance of Report.
6896 6897 6898 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6896 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. Creation timestamp.
Corresponds to the JSON property createTime
6858 6859 6860 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6858 def create_time @create_time end |
#description ⇒ String
Free-text description.
Corresponds to the JSON property description
6863 6864 6865 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6863 def description @description end |
#display_name ⇒ String
User-friendly display name. Maximum length is 63 characters.
Corresponds to the JSON property displayName
6868 6869 6870 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6868 def display_name @display_name end |
#name ⇒ String
Output only. Name of resource.
Corresponds to the JSON property name
6873 6874 6875 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6873 def name @name end |
#state ⇒ String
Report creation state.
Corresponds to the JSON property state
6878 6879 6880 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6878 def state @state end |
#summary ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummary
Describes the Summary view of a Report, which contains aggregated values for
all the groups and preference sets included in this Report.
Corresponds to the JSON property summary
6884 6885 6886 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6884 def summary @summary end |
#type ⇒ String
Report type.
Corresponds to the JSON property type
6889 6890 6891 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6889 def type @type end |
#update_time ⇒ String
Output only. Last update timestamp.
Corresponds to the JSON property updateTime
6894 6895 6896 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6894 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6901 6902 6903 6904 6905 6906 6907 6908 6909 6910 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 6901 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @summary = args[:summary] if args.key?(:summary) @type = args[:type] if args.key?(:type) @update_time = args[:update_time] if args.key?(:update_time) end |