Class: Google::Apis::MigrationcenterV1alpha1::ReportExportExecutionResult

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Contains the result of the report export.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportExportExecutionResult

Returns a new instance of ReportExportExecutionResult.



7200
7201
7202
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7200

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#errorGoogle::Apis::MigrationcenterV1alpha1::Status

The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC. Each Status message contains three pieces of data: error code, error message, and error details. You can find out more about this error model and how to work with it in the API Design Guide. Corresponds to the JSON property error



7188
7189
7190
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7188

def error
  @error
end

#output_filesGoogle::Apis::MigrationcenterV1alpha1::OutputFileList

Contains a list of output files. Corresponds to the JSON property outputFiles



7193
7194
7195
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7193

def output_files
  @output_files
end

#signed_urisGoogle::Apis::MigrationcenterV1alpha1::SignedUris

Contains a list of Signed URIs. Corresponds to the JSON property signedUris



7198
7199
7200
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7198

def signed_uris
  @signed_uris
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7205
7206
7207
7208
7209
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7205

def update!(**args)
  @error = args[:error] if args.key?(:error)
  @output_files = args[:output_files] if args.key?(:output_files)
  @signed_uris = args[:signed_uris] if args.key?(:signed_uris)
end