Class: Google::Apis::MigrationcenterV1alpha1::ReportExportExecutionResult
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportExportExecutionResult
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Contains the result of the report export.
Instance Attribute Summary collapse
-
#error ⇒ Google::Apis::MigrationcenterV1alpha1::Status
The
Statustype defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. -
#output_files ⇒ Google::Apis::MigrationcenterV1alpha1::OutputFileList
Contains a list of output files.
-
#signed_uris ⇒ Google::Apis::MigrationcenterV1alpha1::SignedUris
Contains a list of Signed URIs.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportExportExecutionResult
constructor
A new instance of ReportExportExecutionResult.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportExportExecutionResult
Returns a new instance of ReportExportExecutionResult.
7075 7076 7077 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7075 def initialize(**args) update!(**args) end |
Instance Attribute Details
#error ⇒ Google::Apis::MigrationcenterV1alpha1::Status
The Status type defines a logical error model that is suitable for different
programming environments, including REST APIs and RPC APIs. It is used by
gRPC. Each Status message contains three pieces of
data: error code, error message, and error details. You can find out more
about this error model and how to work with it in the API Design Guide.
Corresponds to the JSON property error
7063 7064 7065 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7063 def error @error end |
#output_files ⇒ Google::Apis::MigrationcenterV1alpha1::OutputFileList
Contains a list of output files.
Corresponds to the JSON property outputFiles
7068 7069 7070 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7068 def output_files @output_files end |
#signed_uris ⇒ Google::Apis::MigrationcenterV1alpha1::SignedUris
Contains a list of Signed URIs.
Corresponds to the JSON property signedUris
7073 7074 7075 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7073 def signed_uris @signed_uris end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7080 7081 7082 7083 7084 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7080 def update!(**args) @error = args[:error] if args.key?(:error) @output_files = args[:output_files] if args.key?(:output_files) @signed_uris = args[:signed_uris] if args.key?(:signed_uris) end |