Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryGroupPreferenceSetFinding
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportSummaryGroupPreferenceSetFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Summary Findings for a specific Group/PreferenceSet combination.
Instance Attribute Summary collapse
-
#database_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummaryDatabaseFinding
DatabaseFinding contains an aggregate costs and shapes for a single database type.
-
#description ⇒ String
Description for the Preference Set.
-
#display_name ⇒ String
Display Name of the Preference Set Corresponds to the JSON property
displayName. -
#machine_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineFinding
A set of findings that applies to assets of type Virtual/Physical Machine.
-
#machine_preferences ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachinePreferences
VirtualMachinePreferences enables you to create sets of preferences, for example, a geographical location and pricing track, for your migrated virtual machines.
-
#monthly_cost_compute ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_database_backup ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_database_licensing ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_gcve_protected ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_network_egress ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_os_license ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_other ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_portable_vmware_license ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_storage ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#monthly_cost_total ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
-
#preference_set ⇒ Google::Apis::MigrationcenterV1alpha1::PreferenceSet
The preferences that apply to all assets in a given context.
-
#preferred_region ⇒ String
Target region for this Preference Set Corresponds to the JSON property
preferredRegion. -
#pricing_track ⇒ String
Text describing the pricing track specified for this Preference Set Corresponds to the JSON property
pricingTrack. -
#sole_tenant_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantFinding
A set of findings that applies to assets destined for Sole-Tenant nodes.
-
#top_priority ⇒ String
Text describing the business priority specified for this Preference Set Corresponds to the JSON property
topPriority. -
#vmware_engine_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareEngineFinding
A set of findings that applies to assets destined for VMWare Engine.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummaryGroupPreferenceSetFinding
constructor
A new instance of ReportSummaryGroupPreferenceSetFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummaryGroupPreferenceSetFinding
Returns a new instance of ReportSummaryGroupPreferenceSetFinding.
7544 7545 7546 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7544 def initialize(**args) update!(**args) end |
Instance Attribute Details
#database_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummaryDatabaseFinding
DatabaseFinding contains an aggregate costs and shapes for a single database
type.
Corresponds to the JSON property databaseFinding
7439 7440 7441 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7439 def database_finding @database_finding end |
#description ⇒ String
Description for the Preference Set.
Corresponds to the JSON property description
7444 7445 7446 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7444 def description @description end |
#display_name ⇒ String
Display Name of the Preference Set
Corresponds to the JSON property displayName
7449 7450 7451 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7449 def display_name @display_name end |
#machine_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineFinding
A set of findings that applies to assets of type Virtual/Physical Machine.
Corresponds to the JSON property machineFinding
7454 7455 7456 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7454 def machine_finding @machine_finding end |
#machine_preferences ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachinePreferences
VirtualMachinePreferences enables you to create sets of preferences, for
example, a geographical location and pricing track, for your migrated virtual
machines. The set of preferences influence recommendations for migrating
virtual machine assets.
Corresponds to the JSON property machinePreferences
7462 7463 7464 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7462 def machine_preferences @machine_preferences end |
#monthly_cost_compute ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostCompute
7467 7468 7469 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7467 def monthly_cost_compute @monthly_cost_compute end |
#monthly_cost_database_backup ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostDatabaseBackup
7472 7473 7474 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7472 def monthly_cost_database_backup @monthly_cost_database_backup end |
#monthly_cost_database_licensing ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostDatabaseLicensing
7477 7478 7479 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7477 def monthly_cost_database_licensing @monthly_cost_database_licensing end |
#monthly_cost_gcve_protected ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostGcveProtected
7482 7483 7484 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7482 def monthly_cost_gcve_protected @monthly_cost_gcve_protected end |
#monthly_cost_network_egress ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostNetworkEgress
7487 7488 7489 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7487 def monthly_cost_network_egress @monthly_cost_network_egress end |
#monthly_cost_os_license ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostOsLicense
7492 7493 7494 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7492 def monthly_cost_os_license @monthly_cost_os_license end |
#monthly_cost_other ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostOther
7497 7498 7499 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7497 def monthly_cost_other @monthly_cost_other end |
#monthly_cost_portable_vmware_license ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostPortableVmwareLicense
7502 7503 7504 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7502 def monthly_cost_portable_vmware_license @monthly_cost_portable_vmware_license end |
#monthly_cost_storage ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostStorage
7507 7508 7509 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7507 def monthly_cost_storage @monthly_cost_storage end |
#monthly_cost_total ⇒ Google::Apis::MigrationcenterV1alpha1::Money
Represents an amount of money with its currency type.
Corresponds to the JSON property monthlyCostTotal
7512 7513 7514 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7512 def monthly_cost_total @monthly_cost_total end |
#preference_set ⇒ Google::Apis::MigrationcenterV1alpha1::PreferenceSet
The preferences that apply to all assets in a given context.
Corresponds to the JSON property preferenceSet
7517 7518 7519 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7517 def preference_set @preference_set end |
#preferred_region ⇒ String
Target region for this Preference Set
Corresponds to the JSON property preferredRegion
7522 7523 7524 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7522 def preferred_region @preferred_region end |
#pricing_track ⇒ String
Text describing the pricing track specified for this Preference Set
Corresponds to the JSON property pricingTrack
7527 7528 7529 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7527 def pricing_track @pricing_track end |
#sole_tenant_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantFinding
A set of findings that applies to assets destined for Sole-Tenant nodes.
Corresponds to the JSON property soleTenantFinding
7532 7533 7534 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7532 def sole_tenant_finding @sole_tenant_finding end |
#top_priority ⇒ String
Text describing the business priority specified for this Preference Set
Corresponds to the JSON property topPriority
7537 7538 7539 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7537 def top_priority @top_priority end |
#vmware_engine_finding ⇒ Google::Apis::MigrationcenterV1alpha1::ReportSummaryVmWareEngineFinding
A set of findings that applies to assets destined for VMWare Engine.
Corresponds to the JSON property vmwareEngineFinding
7542 7543 7544 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7542 def vmware_engine_finding @vmware_engine_finding end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7549 7550 7551 7552 7553 7554 7555 7556 7557 7558 7559 7560 7561 7562 7563 7564 7565 7566 7567 7568 7569 7570 7571 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7549 def update!(**args) @database_finding = args[:database_finding] if args.key?(:database_finding) @description = args[:description] if args.key?(:description) @display_name = args[:display_name] if args.key?(:display_name) @machine_finding = args[:machine_finding] if args.key?(:machine_finding) @machine_preferences = args[:machine_preferences] if args.key?(:machine_preferences) @monthly_cost_compute = args[:monthly_cost_compute] if args.key?(:monthly_cost_compute) @monthly_cost_database_backup = args[:monthly_cost_database_backup] if args.key?(:monthly_cost_database_backup) @monthly_cost_database_licensing = args[:monthly_cost_database_licensing] if args.key?(:monthly_cost_database_licensing) @monthly_cost_gcve_protected = args[:monthly_cost_gcve_protected] if args.key?(:monthly_cost_gcve_protected) @monthly_cost_network_egress = args[:monthly_cost_network_egress] if args.key?(:monthly_cost_network_egress) @monthly_cost_os_license = args[:monthly_cost_os_license] if args.key?(:monthly_cost_os_license) @monthly_cost_other = args[:monthly_cost_other] if args.key?(:monthly_cost_other) @monthly_cost_portable_vmware_license = args[:monthly_cost_portable_vmware_license] if args.key?(:monthly_cost_portable_vmware_license) @monthly_cost_storage = args[:monthly_cost_storage] if args.key?(:monthly_cost_storage) @monthly_cost_total = args[:monthly_cost_total] if args.key?(:monthly_cost_total) @preference_set = args[:preference_set] if args.key?(:preference_set) @preferred_region = args[:preferred_region] if args.key?(:preferred_region) @pricing_track = args[:pricing_track] if args.key?(:pricing_track) @sole_tenant_finding = args[:sole_tenant_finding] if args.key?(:sole_tenant_finding) @top_priority = args[:top_priority] if args.key?(:top_priority) @vmware_engine_finding = args[:vmware_engine_finding] if args.key?(:vmware_engine_finding) end |