Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A Histogram Chart shows a distribution of values into buckets, showing a count of values which fall into a bucket.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryHistogramChartData

Returns a new instance of ReportSummaryHistogramChartData.



7587
7588
7589
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7587

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bucketsArray<Google::Apis::MigrationcenterV1alpha1::ReportSummaryHistogramChartDataBucket>

Buckets in the histogram. There will be n+1 buckets matching n lower bounds in the request. The first bucket will be from -infinity to the first bound. Subsequent buckets will be between one bound and the next. The final bucket will be from the final bound to infinity. Corresponds to the JSON property buckets



7585
7586
7587
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7585

def buckets
  @buckets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7592
7593
7594
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7592

def update!(**args)
  @buckets = args[:buckets] if args.key?(:buckets)
end