Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineFinding
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineFinding
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A set of findings that applies to assets of type Virtual/Physical Machine.
Instance Attribute Summary collapse
-
#allocated_asset_count ⇒ Fixnum
Count of assets which were allocated.
-
#allocated_disk_types ⇒ Array<String>
assets.
-
#allocated_regions ⇒ Array<String>
Set of regions in which the assets were allocated.
-
#machine_series_allocations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineSeriesAllocation>
Distribution of assets based on the Machine Series.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ReportSummaryMachineFinding
constructor
A new instance of ReportSummaryMachineFinding.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ReportSummaryMachineFinding
Returns a new instance of ReportSummaryMachineFinding.
7806 7807 7808 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7806 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allocated_asset_count ⇒ Fixnum
Count of assets which were allocated.
Corresponds to the JSON property allocatedAssetCount
7788 7789 7790 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7788 def allocated_asset_count @allocated_asset_count end |
#allocated_disk_types ⇒ Array<String>
assets.
Corresponds to the JSON property allocatedDiskTypes
7794 7795 7796 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7794 def allocated_disk_types @allocated_disk_types end |
#allocated_regions ⇒ Array<String>
Set of regions in which the assets were allocated.
Corresponds to the JSON property allocatedRegions
7799 7800 7801 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7799 def allocated_regions @allocated_regions end |
#machine_series_allocations ⇒ Array<Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineSeriesAllocation>
Distribution of assets based on the Machine Series.
Corresponds to the JSON property machineSeriesAllocations
7804 7805 7806 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7804 def machine_series_allocations @machine_series_allocations end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7811 7812 7813 7814 7815 7816 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7811 def update!(**args) @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count) @allocated_disk_types = args[:allocated_disk_types] if args.key?(:allocated_disk_types) @allocated_regions = args[:allocated_regions] if args.key?(:allocated_regions) @machine_series_allocations = args[:machine_series_allocations] if args.key?(:machine_series_allocations) end |