Class: Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A set of findings that applies to assets of type Virtual/Physical Machine.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummaryMachineFinding

Returns a new instance of ReportSummaryMachineFinding.



7656
7657
7658
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7656

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_asset_countFixnum

Count of assets which were allocated. Corresponds to the JSON property allocatedAssetCount

Returns:

  • (Fixnum)


7638
7639
7640
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7638

def allocated_asset_count
  @allocated_asset_count
end

#allocated_disk_typesArray<String>

assets. Corresponds to the JSON property allocatedDiskTypes

Returns:

  • (Array<String>)


7644
7645
7646
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7644

def allocated_disk_types
  @allocated_disk_types
end

#allocated_regionsArray<String>

Set of regions in which the assets were allocated. Corresponds to the JSON property allocatedRegions

Returns:

  • (Array<String>)


7649
7650
7651
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7649

def allocated_regions
  @allocated_regions
end

#machine_series_allocationsArray<Google::Apis::MigrationcenterV1alpha1::ReportSummaryMachineSeriesAllocation>

Distribution of assets based on the Machine Series. Corresponds to the JSON property machineSeriesAllocations



7654
7655
7656
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7654

def machine_series_allocations
  @machine_series_allocations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7661
7662
7663
7664
7665
7666
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7661

def update!(**args)
  @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count)
  @allocated_disk_types = args[:allocated_disk_types] if args.key?(:allocated_disk_types)
  @allocated_regions = args[:allocated_regions] if args.key?(:allocated_regions)
  @machine_series_allocations = args[:machine_series_allocations] if args.key?(:machine_series_allocations)
end