Class: Google::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantFinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

A set of findings that applies to assets destined for Sole-Tenant nodes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReportSummarySoleTenantFinding

Returns a new instance of ReportSummarySoleTenantFinding.



7840
7841
7842
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allocated_asset_countFixnum

Count of assets which are allocated Corresponds to the JSON property allocatedAssetCount

Returns:

  • (Fixnum)


7828
7829
7830
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7828

def allocated_asset_count
  @allocated_asset_count
end

#allocated_regionsArray<String>

Set of regions in which the assets are allocated Corresponds to the JSON property allocatedRegions

Returns:

  • (Array<String>)


7833
7834
7835
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7833

def allocated_regions
  @allocated_regions
end

#node_allocationsArray<Google::Apis::MigrationcenterV1alpha1::ReportSummarySoleTenantNodeAllocation>

Set of per-nodetype allocation records Corresponds to the JSON property nodeAllocations



7838
7839
7840
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7838

def node_allocations
  @node_allocations
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7845
7846
7847
7848
7849
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7845

def update!(**args)
  @allocated_asset_count = args[:allocated_asset_count] if args.key?(:allocated_asset_count)
  @allocated_regions = args[:allocated_regions] if args.key?(:allocated_regions)
  @node_allocations = args[:node_allocations] if args.key?(:node_allocations)
end