Class: Google::Apis::MigrationcenterV1alpha1::RunReportExportJobRequest
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::RunReportExportJobRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A request to run a report export job.
Instance Attribute Summary collapse
-
#request_id ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RunReportExportJobRequest
constructor
A new instance of RunReportExportJobRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RunReportExportJobRequest
Returns a new instance of RunReportExportJobRequest.
7979 7980 7981 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7979 def initialize(**args) update!(**args) end |
Instance Attribute Details
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes after the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
7977 7978 7979 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7977 def request_id @request_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7984 7985 7986 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 7984 def update!(**args) @request_id = args[:request_id] if args.key?(:request_id) end |