Class: Google::Apis::MigrationcenterV1alpha1::Settings
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::Settings
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Describes the Migration Center settings related to the project.
Instance Attribute Summary collapse
-
#customer_consent_for_google_sales_to_access_migration_center ⇒ Boolean
(also: #customer_consent_for_google_sales_to_access_migration_center?)
Customer consent for Google sales to access their Cloud Migration Center project.
-
#disable_cloud_logging ⇒ Boolean
(also: #disable_cloud_logging?)
Disable Cloud Logging for the Migration Center API.
-
#name ⇒ String
Output only.
-
#preference_set ⇒ String
The preference set used by default for a project.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Settings
constructor
A new instance of Settings.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Settings
Returns a new instance of Settings.
8299 8300 8301 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8299 def initialize(**args) update!(**args) end |
Instance Attribute Details
#customer_consent_for_google_sales_to_access_migration_center ⇒ Boolean Also known as: customer_consent_for_google_sales_to_access_migration_center?
Customer consent for Google sales to access their Cloud Migration Center
project.
Corresponds to the JSON property customerConsentForGoogleSalesToAccessMigrationCenter
8279 8280 8281 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8279 def @customer_consent_for_google_sales_to_access_migration_center end |
#disable_cloud_logging ⇒ Boolean Also known as: disable_cloud_logging?
Disable Cloud Logging for the Migration Center API. Users are billed for the
logs.
Corresponds to the JSON property disableCloudLogging
8286 8287 8288 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8286 def disable_cloud_logging @disable_cloud_logging end |
#name ⇒ String
Output only. The name of the resource.
Corresponds to the JSON property name
8292 8293 8294 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8292 def name @name end |
#preference_set ⇒ String
The preference set used by default for a project.
Corresponds to the JSON property preferenceSet
8297 8298 8299 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8297 def preference_set @preference_set end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8304 8305 8306 8307 8308 8309 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8304 def update!(**args) @customer_consent_for_google_sales_to_access_migration_center = args[:customer_consent_for_google_sales_to_access_migration_center] if args.key?(:customer_consent_for_google_sales_to_access_migration_center) @disable_cloud_logging = args[:disable_cloud_logging] if args.key?(:disable_cloud_logging) @name = args[:name] if args.key?(:name) @preference_set = args[:preference_set] if args.key?(:preference_set) end |