Class: Google::Apis::MigrationcenterV1alpha1::Source

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

Source represents an object from which asset information is streamed to Migration Center.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Source

Returns a new instance of Source.



8523
8524
8525
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8523

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. The timestamp when the source was created. Corresponds to the JSON property createTime

Returns:

  • (String)


8468
8469
8470
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8468

def create_time
  @create_time
end

#descriptionString

Free-text description. Corresponds to the JSON property description

Returns:

  • (String)


8473
8474
8475
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8473

def description
  @description
end

#display_nameString

User-friendly display name. Corresponds to the JSON property displayName

Returns:

  • (String)


8478
8479
8480
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8478

def display_name
  @display_name
end

#error_frame_countFixnum

Output only. The number of frames that were reported by the source and contained errors. Corresponds to the JSON property errorFrameCount

Returns:

  • (Fixnum)


8484
8485
8486
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8484

def error_frame_count
  @error_frame_count
end

#is_managedBoolean Also known as: is_managed?

If true, the source is managed by other service(s). Corresponds to the JSON property isManaged

Returns:

  • (Boolean)


8489
8490
8491
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8489

def is_managed
  @is_managed
end

#nameString

Output only. The full name of the source. Corresponds to the JSON property name

Returns:

  • (String)


8495
8496
8497
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8495

def name
  @name
end

#pending_frame_countFixnum

Output only. Number of frames that are still being processed. Corresponds to the JSON property pendingFrameCount

Returns:

  • (Fixnum)


8500
8501
8502
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8500

def pending_frame_count
  @pending_frame_count
end

#priorityFixnum

The information confidence of the source. The higher the value, the higher the confidence. Corresponds to the JSON property priority

Returns:

  • (Fixnum)


8506
8507
8508
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8506

def priority
  @priority
end

#stateString

Output only. The state of the source. Corresponds to the JSON property state

Returns:

  • (String)


8511
8512
8513
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8511

def state
  @state
end

#typeString

Data source type. Corresponds to the JSON property type

Returns:

  • (String)


8516
8517
8518
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8516

def type
  @type
end

#update_timeString

Output only. The timestamp when the source was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


8521
8522
8523
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8521

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8528
8529
8530
8531
8532
8533
8534
8535
8536
8537
8538
8539
8540
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8528

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @description = args[:description] if args.key?(:description)
  @display_name = args[:display_name] if args.key?(:display_name)
  @error_frame_count = args[:error_frame_count] if args.key?(:error_frame_count)
  @is_managed = args[:is_managed] if args.key?(:is_managed)
  @name = args[:name] if args.key?(:name)
  @pending_frame_count = args[:pending_frame_count] if args.key?(:pending_frame_count)
  @priority = args[:priority] if args.key?(:priority)
  @state = args[:state] if args.key?(:state)
  @type = args[:type] if args.key?(:type)
  @update_time = args[:update_time] if args.key?(:update_time)
end