Class: Google::Apis::MigrationcenterV1alpha1::UpdateAssetRequest
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::UpdateAssetRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A request to update an asset.
Instance Attribute Summary collapse
-
#asset ⇒ Google::Apis::MigrationcenterV1alpha1::Asset
An asset represents a resource in your environment.
-
#request_id ⇒ String
Optional.
-
#update_mask ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UpdateAssetRequest
constructor
A new instance of UpdateAssetRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UpdateAssetRequest
Returns a new instance of UpdateAssetRequest.
8925 8926 8927 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8925 def initialize(**args) update!(**args) end |
Instance Attribute Details
#asset ⇒ Google::Apis::MigrationcenterV1alpha1::Asset
An asset represents a resource in your environment. Asset types include
virtual machines and databases.
Corresponds to the JSON property asset
8900 8901 8902 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8900 def asset @asset end |
#request_id ⇒ String
Optional. An optional request ID to identify requests. Specify a unique
request ID so that if you must retry your request, the server will know to
ignore the request if it has already been completed. The server will guarantee
that for at least 60 minutes since the first request. For example, consider a
situation where you make an initial request and the request times out. If you
make the request again with the same request ID, the server can check if
original operation with the same request ID was received, and if so, will
ignore the second request. This prevents clients from accidentally creating
duplicate commitments. The request ID must be a valid UUID with the exception
that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
Corresponds to the JSON property requestId
8914 8915 8916 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8914 def request_id @request_id end |
#update_mask ⇒ String
Required. Field mask is used to specify the fields to be overwritten in the
Asset resource by the update. The values specified in the update_mask field
are relative to the resource, not the full request. A field will be
overwritten if it is in the mask. A single * value in the mask lets you to
overwrite all fields.
Corresponds to the JSON property updateMask
8923 8924 8925 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8923 def update_mask @update_mask end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8930 8931 8932 8933 8934 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8930 def update!(**args) @asset = args[:asset] if args.key?(:asset) @request_id = args[:request_id] if args.key?(:request_id) @update_mask = args[:update_mask] if args.key?(:update_mask) end |