Class: Google::Apis::MigrationcenterV1alpha1::UploadFileInfo
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::UploadFileInfo
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
A resource that contains a URI to which a data file can be uploaded.
Instance Attribute Summary collapse
-
#headers ⇒ Hash<String,String>
Output only.
-
#signed_uri ⇒ String
Output only.
-
#uri_expiration_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadFileInfo
constructor
A new instance of UploadFileInfo.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadFileInfo
Returns a new instance of UploadFileInfo.
8931 8932 8933 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8931 def initialize(**args) update!(**args) end |
Instance Attribute Details
#headers ⇒ Hash<String,String>
Output only. The headers that were used to sign the URL.
Corresponds to the JSON property headers
8919 8920 8921 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8919 def headers @headers end |
#signed_uri ⇒ String
Output only. Upload URI for the file.
Corresponds to the JSON property signedUri
8924 8925 8926 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8924 def signed_uri @signed_uri end |
#uri_expiration_time ⇒ String
Output only. Expiration time of the upload URI.
Corresponds to the JSON property uriExpirationTime
8929 8930 8931 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8929 def uri_expiration_time @uri_expiration_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8936 8937 8938 8939 8940 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8936 def update!(**args) @headers = args[:headers] if args.key?(:headers) @signed_uri = args[:signed_uri] if args.key?(:signed_uri) @uri_expiration_time = args[:uri_expiration_time] if args.key?(:uri_expiration_time) end |