Class: Google::Apis::MigrationcenterV1alpha1::VMwareEngineMachinePreferences
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::VMwareEngineMachinePreferences
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
The type of machines to consider when calculating virtual machine migration insights and recommendations for VMware Engine. Not all machine types are available in all zones and regions.
Instance Attribute Summary collapse
-
#allowed_machine_series ⇒ Array<Google::Apis::MigrationcenterV1alpha1::MachineSeries>
Optional.
-
#protected_nodes ⇒ String
Optional.
-
#storage_only_nodes ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VMwareEngineMachinePreferences
constructor
A new instance of VMwareEngineMachinePreferences.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VMwareEngineMachinePreferences
Returns a new instance of VMwareEngineMachinePreferences.
8966 8967 8968 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8966 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allowed_machine_series ⇒ Array<Google::Apis::MigrationcenterV1alpha1::MachineSeries>
Optional. VMware Engine on Google Cloud machine series to consider for
insights and recommendations. If empty, no restriction is applied on the
machine series.
Corresponds to the JSON property allowedMachineSeries
8954 8955 8956 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8954 def allowed_machine_series @allowed_machine_series end |
#protected_nodes ⇒ String
Optional. Whether to use VMware Engine Protected offering.
Corresponds to the JSON property protectedNodes
8959 8960 8961 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8959 def protected_nodes @protected_nodes end |
#storage_only_nodes ⇒ String
Optional. Whether to use storage-only nodes, if those are available.
Corresponds to the JSON property storageOnlyNodes
8964 8965 8966 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8964 def storage_only_nodes @storage_only_nodes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8971 8972 8973 8974 8975 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8971 def update!(**args) @allowed_machine_series = args[:allowed_machine_series] if args.key?(:allowed_machine_series) @protected_nodes = args[:protected_nodes] if args.key?(:protected_nodes) @storage_only_nodes = args[:storage_only_nodes] if args.key?(:storage_only_nodes) end |