Class: Google::Apis::MigrationcenterV1alpha1::VMwareEngineMachinePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

The type of machines to consider when calculating virtual machine migration insights and recommendations for VMware Engine. Not all machine types are available in all zones and regions.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VMwareEngineMachinePreferences

Returns a new instance of VMwareEngineMachinePreferences.



8841
8842
8843
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allowed_machine_seriesArray<Google::Apis::MigrationcenterV1alpha1::MachineSeries>

Optional. VMware Engine on Google Cloud machine series to consider for insights and recommendations. If empty, no restriction is applied on the machine series. Corresponds to the JSON property allowedMachineSeries



8829
8830
8831
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8829

def allowed_machine_series
  @allowed_machine_series
end

#protected_nodesString

Optional. Whether to use VMware Engine Protected offering. Corresponds to the JSON property protectedNodes

Returns:

  • (String)


8834
8835
8836
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8834

def protected_nodes
  @protected_nodes
end

#storage_only_nodesString

Optional. Whether to use storage-only nodes, if those are available. Corresponds to the JSON property storageOnlyNodes

Returns:

  • (String)


8839
8840
8841
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8839

def storage_only_nodes
  @storage_only_nodes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8846
8847
8848
8849
8850
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8846

def update!(**args)
  @allowed_machine_series = args[:allowed_machine_series] if args.key?(:allowed_machine_series)
  @protected_nodes = args[:protected_nodes] if args.key?(:protected_nodes)
  @storage_only_nodes = args[:storage_only_nodes] if args.key?(:storage_only_nodes)
end