Class: Google::Apis::MigrationcenterV1alpha1::VirtualMachineDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::VirtualMachineDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Details of a VirtualMachine.
Instance Attribute Summary collapse
-
#core_count ⇒ Fixnum
Number of logical CPU cores in the VirtualMachine.
-
#create_time ⇒ String
VM creation timestamp.
-
#disk_partitions ⇒ Google::Apis::MigrationcenterV1alpha1::DiskPartitionDetails
Disk partition details.
-
#guest_os ⇒ Google::Apis::MigrationcenterV1alpha1::GuestOsDetails
Information from Guest-level collections.
-
#memory_mb ⇒ Fixnum
The amount of memory in the VirtualMachine.
-
#os_family ⇒ String
What family the OS belong to, if known.
-
#os_name ⇒ String
The name of the operating system running on the VirtualMachine.
-
#os_version ⇒ String
The version of the operating system running on the virtual machine.
-
#platform ⇒ Google::Apis::MigrationcenterV1alpha1::PlatformDetails
Information about the platform.
-
#power_state ⇒ String
Power state of VM (poweredOn or poweredOff).
-
#vcenter_folder ⇒ String
Folder name in vCenter where asset resides.
-
#vcenter_url ⇒ String
vCenter URL used in collection.
-
#vcenter_vm_id ⇒ String
vCenter VM ID.
-
#vm_architecture ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineArchitectureDetails
Details of the VM architecture.
-
#vm_disks ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineDiskDetails
Details of VM disks.
-
#vm_name ⇒ String
Virtual Machine display name.
-
#vm_network ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineNetworkDetails
Details of network adapters and settings.
-
#vm_uuid ⇒ String
Virtual Machine unique identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VirtualMachineDetails
constructor
A new instance of VirtualMachineDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VirtualMachineDetails
Returns a new instance of VirtualMachineDetails.
9193 9194 9195 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9193 def initialize(**args) update!(**args) end |
Instance Attribute Details
#core_count ⇒ Fixnum
Number of logical CPU cores in the VirtualMachine. Must be non-negative.
Corresponds to the JSON property coreCount
9106 9107 9108 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9106 def core_count @core_count end |
#create_time ⇒ String
VM creation timestamp.
Corresponds to the JSON property createTime
9111 9112 9113 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9111 def create_time @create_time end |
#disk_partitions ⇒ Google::Apis::MigrationcenterV1alpha1::DiskPartitionDetails
Disk partition details.
Corresponds to the JSON property diskPartitions
9116 9117 9118 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9116 def disk_partitions @disk_partitions end |
#guest_os ⇒ Google::Apis::MigrationcenterV1alpha1::GuestOsDetails
Information from Guest-level collections.
Corresponds to the JSON property guestOs
9121 9122 9123 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9121 def guest_os @guest_os end |
#memory_mb ⇒ Fixnum
The amount of memory in the VirtualMachine. Must be non-negative.
Corresponds to the JSON property memoryMb
9126 9127 9128 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9126 def memory_mb @memory_mb end |
#os_family ⇒ String
What family the OS belong to, if known.
Corresponds to the JSON property osFamily
9131 9132 9133 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9131 def os_family @os_family end |
#os_name ⇒ String
The name of the operating system running on the VirtualMachine.
Corresponds to the JSON property osName
9136 9137 9138 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9136 def os_name @os_name end |
#os_version ⇒ String
The version of the operating system running on the virtual machine.
Corresponds to the JSON property osVersion
9141 9142 9143 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9141 def os_version @os_version end |
#platform ⇒ Google::Apis::MigrationcenterV1alpha1::PlatformDetails
Information about the platform.
Corresponds to the JSON property platform
9146 9147 9148 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9146 def platform @platform end |
#power_state ⇒ String
Power state of VM (poweredOn or poweredOff).
Corresponds to the JSON property powerState
9151 9152 9153 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9151 def power_state @power_state end |
#vcenter_folder ⇒ String
Folder name in vCenter where asset resides.
Corresponds to the JSON property vcenterFolder
9156 9157 9158 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9156 def vcenter_folder @vcenter_folder end |
#vcenter_url ⇒ String
vCenter URL used in collection.
Corresponds to the JSON property vcenterUrl
9161 9162 9163 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9161 def vcenter_url @vcenter_url end |
#vcenter_vm_id ⇒ String
vCenter VM ID.
Corresponds to the JSON property vcenterVmId
9166 9167 9168 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9166 def vcenter_vm_id @vcenter_vm_id end |
#vm_architecture ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineArchitectureDetails
Details of the VM architecture.
Corresponds to the JSON property vmArchitecture
9171 9172 9173 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9171 def vm_architecture @vm_architecture end |
#vm_disks ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineDiskDetails
Details of VM disks.
Corresponds to the JSON property vmDisks
9176 9177 9178 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9176 def vm_disks @vm_disks end |
#vm_name ⇒ String
Virtual Machine display name.
Corresponds to the JSON property vmName
9181 9182 9183 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9181 def vm_name @vm_name end |
#vm_network ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineNetworkDetails
Details of network adapters and settings.
Corresponds to the JSON property vmNetwork
9186 9187 9188 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9186 def vm_network @vm_network end |
#vm_uuid ⇒ String
Virtual Machine unique identifier.
Corresponds to the JSON property vmUuid
9191 9192 9193 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9191 def vm_uuid @vm_uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9198 9199 9200 9201 9202 9203 9204 9205 9206 9207 9208 9209 9210 9211 9212 9213 9214 9215 9216 9217 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9198 def update!(**args) @core_count = args[:core_count] if args.key?(:core_count) @create_time = args[:create_time] if args.key?(:create_time) @disk_partitions = args[:disk_partitions] if args.key?(:disk_partitions) @guest_os = args[:guest_os] if args.key?(:guest_os) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @os_family = args[:os_family] if args.key?(:os_family) @os_name = args[:os_name] if args.key?(:os_name) @os_version = args[:os_version] if args.key?(:os_version) @platform = args[:platform] if args.key?(:platform) @power_state = args[:power_state] if args.key?(:power_state) @vcenter_folder = args[:vcenter_folder] if args.key?(:vcenter_folder) @vcenter_url = args[:vcenter_url] if args.key?(:vcenter_url) @vcenter_vm_id = args[:vcenter_vm_id] if args.key?(:vcenter_vm_id) @vm_architecture = args[:vm_architecture] if args.key?(:vm_architecture) @vm_disks = args[:vm_disks] if args.key?(:vm_disks) @vm_name = args[:vm_name] if args.key?(:vm_name) @vm_network = args[:vm_network] if args.key?(:vm_network) @vm_uuid = args[:vm_uuid] if args.key?(:vm_uuid) end |