Class: Google::Apis::MigrationcenterV1alpha1::VirtualMachineDetails
- Inherits:
-
Object
- Object
- Google::Apis::MigrationcenterV1alpha1::VirtualMachineDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb
Overview
Details of a VirtualMachine.
Instance Attribute Summary collapse
-
#core_count ⇒ Fixnum
Number of logical CPU cores in the VirtualMachine.
-
#create_time ⇒ String
VM creation timestamp.
-
#disk_partitions ⇒ Google::Apis::MigrationcenterV1alpha1::DiskPartitionDetails
Disk partition details.
-
#guest_os ⇒ Google::Apis::MigrationcenterV1alpha1::GuestOsDetails
Information from Guest-level collections.
-
#memory_mb ⇒ Fixnum
The amount of memory in the VirtualMachine.
-
#os_family ⇒ String
What family the OS belong to, if known.
-
#os_name ⇒ String
The name of the operating system running on the VirtualMachine.
-
#os_version ⇒ String
The version of the operating system running on the virtual machine.
-
#platform ⇒ Google::Apis::MigrationcenterV1alpha1::PlatformDetails
Information about the platform.
-
#power_state ⇒ String
Power state of VM (poweredOn or poweredOff).
-
#vcenter_folder ⇒ String
Folder name in vCenter where asset resides.
-
#vcenter_url ⇒ String
vCenter URL used in collection.
-
#vcenter_vm_id ⇒ String
vCenter VM ID.
-
#vm_architecture ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineArchitectureDetails
Details of the VM architecture.
-
#vm_disks ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineDiskDetails
Details of VM disks.
-
#vm_name ⇒ String
Virtual Machine display name.
-
#vm_network ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineNetworkDetails
Details of network adapters and settings.
-
#vm_uuid ⇒ String
Virtual Machine unique identifier.
Instance Method Summary collapse
-
#initialize(**args) ⇒ VirtualMachineDetails
constructor
A new instance of VirtualMachineDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ VirtualMachineDetails
Returns a new instance of VirtualMachineDetails.
9068 9069 9070 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9068 def initialize(**args) update!(**args) end |
Instance Attribute Details
#core_count ⇒ Fixnum
Number of logical CPU cores in the VirtualMachine. Must be non-negative.
Corresponds to the JSON property coreCount
8981 8982 8983 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8981 def core_count @core_count end |
#create_time ⇒ String
VM creation timestamp.
Corresponds to the JSON property createTime
8986 8987 8988 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8986 def create_time @create_time end |
#disk_partitions ⇒ Google::Apis::MigrationcenterV1alpha1::DiskPartitionDetails
Disk partition details.
Corresponds to the JSON property diskPartitions
8991 8992 8993 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8991 def disk_partitions @disk_partitions end |
#guest_os ⇒ Google::Apis::MigrationcenterV1alpha1::GuestOsDetails
Information from Guest-level collections.
Corresponds to the JSON property guestOs
8996 8997 8998 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 8996 def guest_os @guest_os end |
#memory_mb ⇒ Fixnum
The amount of memory in the VirtualMachine. Must be non-negative.
Corresponds to the JSON property memoryMb
9001 9002 9003 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9001 def memory_mb @memory_mb end |
#os_family ⇒ String
What family the OS belong to, if known.
Corresponds to the JSON property osFamily
9006 9007 9008 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9006 def os_family @os_family end |
#os_name ⇒ String
The name of the operating system running on the VirtualMachine.
Corresponds to the JSON property osName
9011 9012 9013 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9011 def os_name @os_name end |
#os_version ⇒ String
The version of the operating system running on the virtual machine.
Corresponds to the JSON property osVersion
9016 9017 9018 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9016 def os_version @os_version end |
#platform ⇒ Google::Apis::MigrationcenterV1alpha1::PlatformDetails
Information about the platform.
Corresponds to the JSON property platform
9021 9022 9023 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9021 def platform @platform end |
#power_state ⇒ String
Power state of VM (poweredOn or poweredOff).
Corresponds to the JSON property powerState
9026 9027 9028 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9026 def power_state @power_state end |
#vcenter_folder ⇒ String
Folder name in vCenter where asset resides.
Corresponds to the JSON property vcenterFolder
9031 9032 9033 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9031 def vcenter_folder @vcenter_folder end |
#vcenter_url ⇒ String
vCenter URL used in collection.
Corresponds to the JSON property vcenterUrl
9036 9037 9038 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9036 def vcenter_url @vcenter_url end |
#vcenter_vm_id ⇒ String
vCenter VM ID.
Corresponds to the JSON property vcenterVmId
9041 9042 9043 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9041 def vcenter_vm_id @vcenter_vm_id end |
#vm_architecture ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineArchitectureDetails
Details of the VM architecture.
Corresponds to the JSON property vmArchitecture
9046 9047 9048 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9046 def vm_architecture @vm_architecture end |
#vm_disks ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineDiskDetails
Details of VM disks.
Corresponds to the JSON property vmDisks
9051 9052 9053 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9051 def vm_disks @vm_disks end |
#vm_name ⇒ String
Virtual Machine display name.
Corresponds to the JSON property vmName
9056 9057 9058 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9056 def vm_name @vm_name end |
#vm_network ⇒ Google::Apis::MigrationcenterV1alpha1::VirtualMachineNetworkDetails
Details of network adapters and settings.
Corresponds to the JSON property vmNetwork
9061 9062 9063 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9061 def vm_network @vm_network end |
#vm_uuid ⇒ String
Virtual Machine unique identifier.
Corresponds to the JSON property vmUuid
9066 9067 9068 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9066 def vm_uuid @vm_uuid end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9073 9074 9075 9076 9077 9078 9079 9080 9081 9082 9083 9084 9085 9086 9087 9088 9089 9090 9091 9092 |
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9073 def update!(**args) @core_count = args[:core_count] if args.key?(:core_count) @create_time = args[:create_time] if args.key?(:create_time) @disk_partitions = args[:disk_partitions] if args.key?(:disk_partitions) @guest_os = args[:guest_os] if args.key?(:guest_os) @memory_mb = args[:memory_mb] if args.key?(:memory_mb) @os_family = args[:os_family] if args.key?(:os_family) @os_name = args[:os_name] if args.key?(:os_name) @os_version = args[:os_version] if args.key?(:os_version) @platform = args[:platform] if args.key?(:platform) @power_state = args[:power_state] if args.key?(:power_state) @vcenter_folder = args[:vcenter_folder] if args.key?(:vcenter_folder) @vcenter_url = args[:vcenter_url] if args.key?(:vcenter_url) @vcenter_vm_id = args[:vcenter_vm_id] if args.key?(:vcenter_vm_id) @vm_architecture = args[:vm_architecture] if args.key?(:vm_architecture) @vm_disks = args[:vm_disks] if args.key?(:vm_disks) @vm_name = args[:vm_name] if args.key?(:vm_name) @vm_network = args[:vm_network] if args.key?(:vm_network) @vm_uuid = args[:vm_uuid] if args.key?(:vm_uuid) end |