Class: Google::Apis::MigrationcenterV1alpha1::VmwareEnginePreferences

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/migrationcenter_v1alpha1/classes.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb,
lib/google/apis/migrationcenter_v1alpha1/representations.rb

Overview

The user preferences relating to Google Cloud VMware Engine target platform.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ VmwareEnginePreferences

Returns a new instance of VmwareEnginePreferences.



9384
9385
9386
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9384

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitment_planString

Commitment plan to consider when calculating costs for virtual machine insights and recommendations. If you are unsure which value to set, a 3 year commitment plan is often a good value to start with. Corresponds to the JSON property commitmentPlan

Returns:

  • (String)


9341
9342
9343
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9341

def commitment_plan
  @commitment_plan
end

#cpu_overcommit_ratioFloat

CPU overcommit ratio. Acceptable values are between 1.0 and 8.0, with 0.1 increment. Corresponds to the JSON property cpuOvercommitRatio

Returns:

  • (Float)


9347
9348
9349
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9347

def cpu_overcommit_ratio
  @cpu_overcommit_ratio
end

#license_discount_percentageFloat

Optional. Discount percentage for the license offered to you by Broadcom. Must be between 0 and 100. Only valid when service_type is set to SERVICE_TYPE_PORTABLE_LICENSE. Corresponds to the JSON property licenseDiscountPercentage

Returns:

  • (Float)


9354
9355
9356
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9354

def license_discount_percentage
  @license_discount_percentage
end

#machine_preferencesGoogle::Apis::MigrationcenterV1alpha1::VMwareEngineMachinePreferences

The type of machines to consider when calculating virtual machine migration insights and recommendations for VMware Engine. Not all machine types are available in all zones and regions. Corresponds to the JSON property machinePreferences



9361
9362
9363
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9361

def machine_preferences
  @machine_preferences
end

#memory_overcommit_ratioFloat

Memory overcommit ratio. Acceptable values are 1.0, 1.25, 1.5, 1.75 and 2.0. Corresponds to the JSON property memoryOvercommitRatio

Returns:

  • (Float)


9366
9367
9368
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9366

def memory_overcommit_ratio
  @memory_overcommit_ratio
end

#service_typeString

Optional. GCVE service type (fully licensed or portable license). Corresponds to the JSON property serviceType

Returns:

  • (String)


9371
9372
9373
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9371

def service_type
  @service_type
end

#storage_deduplication_compression_ratioFloat

The Deduplication and Compression ratio is based on the logical (Used Before) space required to store data before applying deduplication and compression, in relation to the physical (Used After) space required after applying deduplication and compression. Specifically, the ratio is the Used Before space divided by the Used After space. For example, if the Used Before space is 3 GB, but the physical Used After space is 1 GB, the deduplication and compression ratio is 3x. Acceptable values are between 1.0 and 4.0. Corresponds to the JSON property storageDeduplicationCompressionRatio

Returns:

  • (Float)


9382
9383
9384
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9382

def storage_deduplication_compression_ratio
  @storage_deduplication_compression_ratio
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9389
9390
9391
9392
9393
9394
9395
9396
9397
# File 'lib/google/apis/migrationcenter_v1alpha1/classes.rb', line 9389

def update!(**args)
  @commitment_plan = args[:commitment_plan] if args.key?(:commitment_plan)
  @cpu_overcommit_ratio = args[:cpu_overcommit_ratio] if args.key?(:cpu_overcommit_ratio)
  @license_discount_percentage = args[:license_discount_percentage] if args.key?(:license_discount_percentage)
  @machine_preferences = args[:machine_preferences] if args.key?(:machine_preferences)
  @memory_overcommit_ratio = args[:memory_overcommit_ratio] if args.key?(:memory_overcommit_ratio)
  @service_type = args[:service_type] if args.key?(:service_type)
  @storage_deduplication_compression_ratio = args[:storage_deduplication_compression_ratio] if args.key?(:storage_deduplication_compression_ratio)
end